% Auto-generated chapter 28 for abudawud
% Hadiths in this chapter: 119

\hadithdefcmd{abudawud}{3736}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى الْوَلِيمَةِ فَلْيَأْتِهَا ‏"‏ ‏.‏\hadithno{3736}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5173) Sahih Muslim (1429)}\hadithtrans{‘Abd Allah b. ‘Umar reported the Prophet(ﷺ) as sayings:when one of you is invited for a wedding feast, he must attend it}}
\hadithdefcmd{abudawud}{3737}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَعْنَاهُ زَادَ ‏ "‏ فَإِنْ كَانَ مُفْطِرًا فَلْيَطْعَمْ وَإِنْ كَانَ صَائِمًا فَلْيَدْعُ ‏"‏ ‏.‏\hadithno{3737}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1429)}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn ‘Umar to the same effect through a different chain of narrators. This version has the additional words:If he is not fasting, he should eat, and if he is fasting, he should leave it}}
\hadithdefcmd{abudawud}{3738}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَعَا أَحَدُكُمْ أَخَاهُ فَلْيُجِبْ عُرْسًا كَانَ أَوْ نَحْوَهُ ‏"‏ ‏.‏\hadithno{3738}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim (1429)}\hadithtrans{Ibn ‘Umar reported the Messenger of Allah(ﷺ) as saying:if one of you invites his brother, he should accept(the invitation), whether it is a wedding feast or something of that nature}}
\hadithdefcmd{abudawud}{3739}{حَدَّثَنَا ابْنُ الْمُصَفَّى، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا الزُّبَيْدِيُّ، عَنْ نَافِعٍ، بِإِسْنَادِ أَيُّوبَ وَمَعْنَاهُ ‏.‏\hadithno{3739}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih Muslim (1429)}\hadithtrans{The tradition mentioned above has also been transmitted by Nafi’ to the same effect through the chain of narrators as mentioned in Ayyub}}
\hadithdefcmd{abudawud}{3740}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ دُعِيَ فَلْيُجِبْ فَإِنْ شَاءَ طَعِمَ وَإِنْ شَاءَ تَرَكَ ‏"‏ ‏.‏\hadithno{3740}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1430)}\hadithtrans{Jabir reported the Messenger of Allah(ﷺ) as sayings:when one of you is invited to a meal, he must accept. If he wishes he may eat, but if he wishes(to leave), he may leave}}
\hadithdefcmd{abudawud}{3741}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا دُرُسْتُ بْنُ زِيَادٍ، عَنْ أَبَانَ بْنِ طَارِقٍ، عَنْ طَارِقٍ، عَنْ نَافِعٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ دُعِيَ فَلَمْ يُجِبْ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ وَمَنْ دَخَلَ عَلَى غَيْرِ دَعْوَةٍ دَخَلَ سَارِقًا وَخَرَجَ مُغِيرًا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ أَبَانُ بْنُ طَارِقٍ مَجْهُولٌ ‏.‏\hadithno{3741}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: He who does not accept an invitation which he receives has disobeyed Allah and His Apostle, and he who enters without invitation enters as a thief and goes out as a raider. Abu Dawud said: Aban bin Tariq is unknown}}
\hadithdefcmd{abudawud}{3742}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ شَرُّ الطَّعَامِ طَعَامُ الْوَلِيمَةِ يُدْعَى لَهَا الأَغْنِيَاءُ وَيُتْرَكُ الْمَسَاكِينُ وَمَنْ لَمْ يَأْتِ الدَّعْوَةَ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ ‏.‏\hadithno{3742}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Sahih Bukhari (5177) Sahih Muslim (1432)}\hadithtrans{Abu Hurairah said:The worst kind of food is that at a wedding feast to which the rich are invited and from which the poor are left out. If anyone does not attend the feast to which he was invited, he has disobeyed Allah and His Apostle (may peace upon him)}}
\hadithdefcmd{abudawud}{3743}{حَدَّثَنَا مُسَدَّدٌ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، قَالَ ذُكِرَ تَزْوِيجُ زَيْنَبَ بِنْتِ جَحْشٍ عِنْدَ أَنَسِ بْنِ مَالِكٍ فَقَالَ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَوْلَمَ عَلَى أَحَدٍ مِنْ نِسَائِهِ مَا أَوْلَمَ عَلَيْهَا أَوْلَمَ بِشَاةٍ ‏.‏\hadithno{3743}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5171) Sahih Muslim (1428)}\hadithtrans{Thabit said:The marriage of Zainab daughter of Jahsh was mentioned before Anas b. Malik. He said: I did not see that the Messenger of Allah (ﷺ) held such a wedding feast for any of his wives as he did for her. He held a wedding feast with a sheep}}
\hadithdefcmd{abudawud}{3744}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا وَائِلُ بْنُ دَاوُدَ، عَنِ ابْنِهِ، بَكْرِ بْنِ وَائِلٍ عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَوْلَمَ عَلَى صَفِيَّةَ بِسَوِيقٍ وَتَمْرٍ ‏.‏\hadithno{3744}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) held a wedding feast for Safiyyah with meal and dates}}
\hadithdefcmd{abudawud}{3745}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ الثَّقَفِيِّ، عَنْ رَجُلٍ، أَعْوَرَ مِنْ ثَقِيفٍ كَانَ يُقَالُ لَهُ مَعْرُوفًا - أَىْ يُثْنَى عَلَيْهِ خَيْرًا إِنْ لَمْ يَكُنِ اسْمُهُ زُهَيْرُ بْنُ عُثْمَانَ فَلاَ أَدْرِي مَا اسْمُهُ - أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْوَلِيمَةُ أَوَّلُ يَوْمٍ حَقٌّ وَالثَّانِي مَعْرُوفٌ وَالْيَوْمُ الثَّالِثُ سُمْعَةٌ وَرِيَاءٌ ‏"‏ ‏.‏ قَالَ قَتَادَةُ وَحَدَّثَنِي رَجُلٌ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ دُعِيَ أَوَّلَ يَوْمٍ فَأَجَابَ وَدُعِيَ الْيَوْمَ الثَّانِي فَأَجَابَ وَدُعِيَ الْيَوْمَ الثَّالِثَ فَلَمْ يُجِبْ وَقَالَ أَهْلُ سُمْعَةٍ وَرِيَاءٍ ‏.‏\hadithno{3745}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zubayr ibn Uthman: The Prophet (ﷺ) said: The wedding feast on the first day is a duty, that on the second is a good practice, but that on the third day is to make men hear of it and show it to them. Qatadah said: A man told me that Sa'id ibn al-Musayyab was invited (to a wedding feast on the first day and he accepted it. He was again invited on the second day, and he accepted. When he was invited on the third day, he did not accept; he said: They are the people who make men hear of it and show it to them)}}
\hadithdefcmd{abudawud}{3746}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، بِهَذِهِ الْقِصَّةِ قَالَ فَدُعِيَ الْيَوْمَ الثَّالِثَ فَلَمْ يُجِبْ وَحَصَبَ الرَّسُولَ ‏.‏\hadithno{3746}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Qatadah reported this story from Sa’id b. al-Musayyab. This version adds:When he was invited on the third day, he did not accept but threw pebbles on the messenger}}
\hadithdefcmd{abudawud}{3747}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرٍ، قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ نَحَرَ جَزُورًا أَوْ بَقَرَةً ‏.‏\hadithno{3747}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3089)}\hadithtrans{Narrated Jabir ibn Abdullah: When the Prophet (ﷺ) returned to Medina, he would slaughter a camel or a cow}}
\hadithdefcmd{abudawud}{3748}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي شُرَيْحٍ الْكَعْبِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ جَائِزَتُهُ يَوْمُهُ وَلَيْلَتُهُ الضِّيَافَةُ ثَلاَثَةُ أَيَّامٍ وَمَا بَعْدَ ذَلِكَ فَهُوَ صَدَقَةٌ وَلاَ يَحِلُّ لَهُ أَنْ يَثْوِيَ عِنْدَهُ حَتَّى يُحْرِجَهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قُرِئَ عَلَى الْحَارِثِ بْنِ مِسْكِينٍ وَأَنَا شَاهِدٌ أَخْبَرَكُمْ أَشْهَبُ قَالَ وَسُئِلَ مَالِكٌ عَنْ قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ جَائِزَتُهُ يَوْمٌ وَلَيْلَةٌ ‏"‏ ‏.‏ فَقَالَ يُكْرِمُهُ وَيُتْحِفُهُ وَيَحْفَظُهُ يَوْمًا وَلَيْلَةً وَثَلاَثَةُ أَيَّامٍ ضِيَافَةٌ ‏.‏\hadithno{3748}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6135) Sahih Muslim (48 After  1726)}\hadithtrans{Abu Shuraih al-Ka’bi reported the Messenger of Allah(ﷺ) as sayings:He who believes in Allah and the Last Day should honour his guest provisions for the road are what will serve for a day and night: hospitality extends for three days; what goes after that is sadaqah(charity): and it is not allowable that a guest should stay till he makes himself an encumbrance. Abu Dawud said: Malik was asked about the saying of the Prophet: "Provisions for the road what will serve for a day a night." He said: He should honor him, present him some gift, and protect him for a day and night, and hospitality for three days}}
\hadithdefcmd{abudawud}{3749}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَمُحَمَّدُ بْنُ مَحْبُوبٍ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ عَاصِمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الضِّيَافَةُ ثَلاَثَةُ أَيَّامٍ فَمَا سِوَى ذَلِكَ فَهُوَ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{3749}\hadithgrade{Al-Albani: Hasan Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Hospitality extend for three days, and what goes beyond that is sadaqah (charity)}}
\hadithdefcmd{abudawud}{3750}{حَدَّثَنَا مُسَدَّدٌ، وَخَلَفُ بْنُ هِشَامٍ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ عَامِرٍ، عَنْ أَبِي كَرِيمَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْلَةُ الضَّيْفِ حَقٌّ عَلَى كُلِّ مُسْلِمٍ فَمَنْ أَصْبَحَ بِفِنَائِهِ فَهُوَ عَلَيْهِ دَيْنٌ إِنْ شَاءَ اقْتَضَى وَإِنْ شَاءَ تَرَكَ ‏"‏ ‏.‏\hadithno{3750}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuKarimah: The Prophet (ﷺ) said: It is a duty of every Muslim (to provide hospitality) to a guest for a night. If anyone comes in the morning to his house, it is a debt due to him. If he wishes, he may fulfil it, and if he wishes he may leave it}}
\hadithdefcmd{abudawud}{3751}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي أَبُو الْجُودِيِّ، عَنْ سَعِيدِ بْنِ أَبِي الْمُهَاجِرِ، عَنِ الْمِقْدَامِ أَبِي كَرِيمَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا رَجُلٍ أَضَافَ قَوْمًا فَأَصْبَحَ الضَّيْفُ مَحْرُومًا فَإِنَّ نَصْرَهُ حَقٌّ عَلَى كُلِّ مُسْلِمٍ حَتَّى يَأْخُذَ بِقِرَى لَيْلَةٍ مِنْ زَرْعِهِ وَمَالِهِ ‏"‏ ‏.‏\hadithno{3751}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Miqdam AbuKarimah: The Prophet (ﷺ) said: If any Muslim is a guest of people and is given nothing, it is the duty of every Muslim to help him to the extent of taking for him from their crop and property for the entertainment of one night}}
\hadithdefcmd{abudawud}{3752}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّهُ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ إِنَّكَ تَبْعَثُنَا فَنَنْزِلُ بِقَوْمٍ فَمَا يَقْرُونَنَا فَمَا تَرَى فَقَالَ لَنَا رَسُولُ اللَّهِ ‏ "‏ إِنْ نَزَلْتُمْ بِقَوْمٍ فَأَمَرُوا لَكُمْ بِمَا يَنْبَغِي لِلضَّيْفِ فَاقْبَلُوا فَإِنْ لَمْ يَفْعَلُوا فَخُذُوا مِنْهُمْ حَقَّ الضَّيْفِ الَّذِي يَنْبَغِي لَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذِهِ حُجَّةٌ لِلرَّجُلِ يَأْخُذُ الشَّىْءَ إِذَا كَانَ لَهُ حَقًّا ‏.‏\hadithno{3752}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6137) Sahih Muslim (1727)}\hadithtrans{‘Uqbah b. ‘Amir said:we said: Messenger of Allah! You send us out and we come to people who do not give hospitality, so what is your opinion? The Messenger of Allah(ﷺ) said: If you come to people who order for you what is fitting for a guest, accept it; but if they do not, take from them what is fitting for them to give to a guest. Abu Dawud said: And this is an authority for a man to take a thing if it is due to him}}
\hadithdefcmd{abudawud}{3753}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ لاَ تَأْكُلُوا أَمْوَالَكُمْ بَيْنَكُمْ بِالْبَاطِلِ إِلاَّ أَنْ تَكُونَ تِجَارَةً عَنْ تَرَاضٍ مِنْكُمْ ‏\}‏ فَكَانَ الرَّجُلُ يُحْرَجُ أَنْ يَأْكُلَ عِنْدَ أَحَدٍ مِنَ النَّاسِ بَعْدَ مَا نَزَلَتْ هَذِهِ الآيَةُ فَنَسَخَ ذَلِكَ الآيَةُ الَّتِي فِي النُّورِ قَالَ ‏\{‏ لَيْسَ عَلَيْكُمْ جُنَاحٌ ‏\}‏ ‏\{‏ أَنْ تَأْكُلُوا مِنْ بُيُوتِكُمْ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ أَشْتَاتًا ‏\}‏ كَانَ الرَّجُلُ الْغَنِيُّ يَدْعُو الرَّجُلَ مِنْ أَهْلِهِ إِلَى الطَّعَامِ قَالَ إِنِّي لأَجَّنَّحُ أَنْ آكُلَ مِنْهُ ‏.‏ وَالتَّجَنُّحُ الْحَرَجُ وَيَقُولُ الْمِسْكِينُ أَحَقُّ بِهِ مِنِّي ‏.‏ فَأُحِلَّ فِي ذَلِكَ أَنْ يَأْكُلُوا مِمَّا ذُكِرَ اسْمُ اللَّهِ عَلَيْهِ وَأُحِلَّ طَعَامُ أَهْلِ الْكِتَابِ ‏.‏\hadithno{3753}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah Ibn Abbas: When the verse: "O ye who believe! eat not up your property among yourselves in vanities, but let there be amongst you traffic and trade by mutual good will" was revealed, a man thought it a sin to eat in the house of another man after the revelation of this verse. Then this (injunction) was revealed by the verse in Surat an-Nur: "No blame on you whether you eat in company or separately." When a rich man (after revelation) invited a man from his people to eat food in his house, he would say: I consider it a sin to eat from it, and he said: a poor man is more entitled to it than I. The Arabic word tajannah means sin or fault. It was then declared lawful to eat something on which the name of Allah was mentioned, and it was made lawful to eat the flesh of an animal slaughtered by the people of the Book}}
\hadithdefcmd{abudawud}{3754}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنِ الزُّبَيْرِ بْنِ خِرِّيتٍ، قَالَ سَمِعْتُ عِكْرِمَةَ، يَقُولُ كَانَ ابْنُ عَبَّاسٍ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ طَعَامِ الْمُتَبَارِيَيْنِ أَنْ يُؤْكَلَ ‏.‏ قَالَ أَبُو دَاوُدَ أَكْثَرُ مَنْ رَوَاهُ عَنْ جَرِيرٍ لاَ يَذْكُرُ فِيهِ ابْنَ عَبَّاسٍ وَهَارُونُ النَّحْوِيُّ ذَكَرَ فِيهِ ابْنَ عَبَّاسٍ أَيْضًا وَحَمَّادُ بْنُ زَيْدٍ لَمْ يَذْكُرِ ابْنَ عَبَّاسٍ ‏.‏\hadithno{3754}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) forbade that the food of two people who were rivalling on another should be eaten Abu Dawud said: Most of those who narrated it from Jarir did not mention the name of Ibn Abbas. Harun al-Nahwi mentioned Ibn 'Abbas in it, and Hammad bin Zaid did not mention Ibn 'Abbas}}
\hadithdefcmd{abudawud}{3755}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، أَخْبَرَنَا حَمَّادٌ، عَنْ سَعِيدِ بْنِ جُمْهَانَ، عَنْ سَفِينَةَ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ رَجُلاً، أَضَافَ عَلِيَّ بْنَ أَبِي طَالِبٍ فَصَنَعَ لَهُ طَعَامًا فَقَالَتْ فَاطِمَةُ لَوْ دَعَوْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَكَلَ مَعَنَا ‏.‏ فَدَعَوْهُ فَجَاءَ فَوَضَعَ يَدَهُ عَلَى عِضَادَتَىِ الْبَابِ فَرَأَى الْقِرَامَ قَدْ ضُرِبَ بِهِ فِي نَاحِيَةِ الْبَيْتِ فَرَجَعَ فَقَالَتْ فَاطِمَةُ لِعَلِيٍّ الْحَقْهُ فَانْظُرْ مَا رَجَعَهُ ‏.‏ فَتَبِعْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا رَدَّكَ فَقَالَ ‏ "‏ إِنَّهُ لَيْسَ لِي أَوْ لِنَبِيٍّ أَنْ يَدْخُلَ بَيْتًا مُزَوَّقًا ‏"‏ ‏.‏\hadithno{3755}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: Safinah AbuAbdurRahman said that a man prepared food for Ali ibn AbuTalib who was his guest, and Fatimah said: I wish we had invited the Messenger of Allah (ﷺ) and he had eaten with us. They invited him, and when he came he put his hands on the side-ports of the door, but when he saw the figured curtain which had been put at the end of the house, he went away. So Fatimah said to Ali: Follow him and see what turned him back. I (Ali) followed him and asked: What turned you back, Messenger of Allah? He replied: It is not fitting for me or for any Prophet to enter a house which is decorated}}
\hadithdefcmd{abudawud}{3756}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ عَبْدِ السَّلاَمِ بْنِ حَرْبٍ، عَنْ أَبِي خَالِدٍ الدَّالاَنِيِّ، عَنْ أَبِي الْعَلاَءِ الأَوْدِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيِّ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اجْتَمَعَ الدَّاعِيَانِ فَأَجِبْ أَقْرَبَهُمَا بَابًا فَإِنَّ أَقْرَبَهُمَا بَابًا أَقْرَبُهُمَا جِوَارًا وَإِنْ سَبَقَ أَحَدُهُمَا فَأَجِبِ الَّذِي سَبَقَ ‏"‏ ‏.‏\hadithno{3756}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbdurRahman al-Himyari: A companion of the Prophet (ﷺ) reported him as saying: When two people come together to issue an invitation, accept that of the one whose door is nearer in neighbourhood, but if one of them comes before the other accept the invitation of the one who comes first}}
\hadithdefcmd{abudawud}{3757}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُسَدَّدٌ، - الْمَعْنَى - قَالَ أَحْمَدُ حَدَّثَنِي يَحْيَى الْقَطَّانُ، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وُضِعَ عَشَاءُ أَحَدِكُمْ وَأُقِيمَتِ الصَّلاَةُ فَلاَ يَقُومُ حَتَّى يَفْرُغَ ‏"‏ ‏.‏ زَادَ مُسَدَّدٌ وَكَانَ عَبْدُ اللَّهِ إِذَا وُضِعَ عَشَاؤُهُ أَوْ حَضَرَ عَشَاؤُهُ لَمْ يَقُمْ حَتَّى يَفْرُغَ وَإِنْ سَمِعَ الإِقَامَةَ وَإِنْ سَمِعَ قِرَاءَةَ الإِمَامِ ‏.‏\hadithno{3757}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (677) Sahih Muslim (559)}\hadithtrans{Ibn ‘Umar reported the Prophet(ﷺ) as sayings:When the evening meal is brought before one of you and the congregational prayer is also ready, he should not get up until he finishes(eating). Musaddad’s version adds: When the evening meal was put before ‘Abd Allah b. ‘Umar, or it was brought to him, he did not get up until he finished it, even if he heard call to prayer(just before it), and even if he heard the recitation of the Qur’an by the leader-in-prayer}}
\hadithdefcmd{abudawud}{3758}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ بَزِيعٍ، حَدَّثَنَا مُعَلَّى، - يَعْنِي ابْنَ مَنْصُورٍ - عَنْ مُحَمَّدِ بْنِ مَيْمُونٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُؤَخِّرِ الصَّلاَةَ لِطَعَامٍ وَلاَ لِغَيْرِهِ ‏"‏ ‏.‏\hadithno{3758}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: Prayer should not be postponed for taking meals nor for any other thing}}
\hadithdefcmd{abudawud}{3759}{حَدَّثَنَا عَلِيُّ بْنُ مُسْلِمٍ الطُّوسِيُّ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، قَالَ كُنْتُ مَعَ أَبِي فِي زَمَانِ ابْنِ الزُّبَيْرِ إِلَى جَنْبِ عَبْدِ اللَّهِ بْنِ عُمَرَ فَقَالَ عَبَّادُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ إِنَّا سَمِعْنَا أَنَّهُ، يُبْدَأُ بِالْعَشَاءِ قَبْلَ الصَّلاَةِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ وَيْحَكَ مَا كَانَ عَشَاؤُهُمْ أَتُرَاهُ كَانَ مِثْلَ عَشَاءِ أَبِيكَ ‏.‏\hadithno{3759}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: Abdullah ibn Ubaydullah ibn Umayr said: I was with my father in the time of Ibn az-Zubayr sitting beside Abdullah ibn Umar. Then Abbad ibn Abdullah ibn az-Zubayr said: We have heard that the evening meal is taken just before the night prayer. Thereupon Abdullah ibn Umar said: Woe to you! what was their evening meal? Do you think it was like the meal of your father?}}
\hadithdefcmd{abudawud}{3760}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا أَيُّوبُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مِنَ الْخَلاَءِ فَقُدِّمَ إِلَيْهِ طَعَامٌ فَقَالُوا أَلاَ نَأْتِيكَ بِوَضُوءٍ فَقَالَ ‏ "‏ إِنَّمَا أُمِرْتُ بِالْوُضُوءِ إِذَا قُمْتُ إِلَى الصَّلاَةِ ‏"‏ ‏.‏\hadithno{3760}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) came out from the privy and was presented to him. They (the people) asked: Should we bring you water for ablution? He replied: I have been commanded to perform ablution when I get up for prayer}}
\hadithdefcmd{abudawud}{3761}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا قَيْسٌ، عَنْ أَبِي هَاشِمٍ، عَنْ زَاذَانَ، عَنْ سَلْمَانَ، قَالَ قَرَأْتُ فِي التَّوْرَاةِ أَنَّ بَرَكَةَ الطَّعَامِ الْوُضُوءُ قَبْلَهُ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ بَرَكَةُ الطَّعَامِ الْوُضُوءُ قَبْلَهُ وَالْوُضُوءُ بَعْدَهُ ‏"‏ ‏.‏ وَكَانَ سُفْيَانُ يَكْرَهُ الْوُضُوءَ قَبْلَ الطَّعَامِ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ ضَعِيفٌ ‏.‏\hadithno{3761}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salman al-Farsi: I read in the Torah that the blessing of food consists in ablution before it. So I mentioned it to the Prophet (ﷺ). He said: The blessing of food consists in ablution before it and ablution after it. Sufyan disapproved of performing ablution before taking food. Abu Dawud said: It is weak}}
\hadithdefcmd{abudawud}{3762}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا عَمِّي، - يَعْنِي سَعِيدَ بْنَ الْحَكَمِ - حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، أَخْبَرَنِي خَالِدُ بْنُ يَزِيدَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ أَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ شِعْبٍ مِنَ الْجَبَلِ وَقَدْ قَضَى حَاجَتَهُ وَبَيْنَ أَيْدِينَا تَمْرٌ عَلَى تُرْسٍ أَوْ حَجَفَةٍ فَدَعَوْنَاهُ فَأَكَلَ مَعَنَا وَمَا مَسَّ مَاءً ‏.‏\hadithno{3762}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) came out from the valley of a mountain where he had eased himself. There were some dried dates on a shield before us. We called him and he ate with us. He did not touch water}}
\hadithdefcmd{abudawud}{3763}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَا عَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم طَعَامًا قَطُّ إِنِ اشْتَهَاهُ أَكَلَهُ وَإِنْ كَرِهَهُ تَرَكَهُ ‏.‏\hadithno{3763}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5409) Sahih Muslim (2064)}\hadithtrans{Abu Hurairah said:The Messenger of Allah (ﷺ) never expressed disapproval of food; if he desired it, he ate it, and if he disliked it, he left it alone}}
\hadithdefcmd{abudawud}{3764}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنِي وَحْشِيُّ بْنُ حَرْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ أَصْحَابَ النَّبِيِّ، صلى الله عليه وسلم قَالُوا يَا رَسُولَ اللَّهِ إِنَّا نَأْكُلُ وَلاَ نَشْبَعُ ‏.‏ قَالَ ‏"‏ فَلَعَلَّكُمْ تَفْتَرِقُونَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ فَاجْتَمِعُوا عَلَى طَعَامِكُمْ وَاذْكُرُوا اسْمَ اللَّهِ عَلَيْهِ يُبَارَكْ لَكُمْ فِيهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ إِذَا كُنْتَ فِي وَلِيمَةٍ فَوُضِعَ الْعَشَاءُ فَلاَ تَأْكُلْ حَتَّى يَأْذَنَ لَكَ صَاحِبُ الدَّارِ ‏.‏\hadithno{3764}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Wahshi ibn Harb: The Companions of the Prophet (ﷺ) said: Messenger of Allah (ﷺ) we eat but we are not satisfied. He said: Perhaps you eat separately. They replied: Yes. He said: If you gather together at your food and mention Allah's name, you will be blessed in it. Abu Dawud said: If you are invited to a wedding feast before you, do not take it until the owner of the house (i.e. the host) allows you (to eat)}}
\hadithdefcmd{abudawud}{3765}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا دَخَلَ الرَّجُلُ بَيْتَهُ فَذَكَرَ اللَّهَ عِنْدَ دُخُولِهِ وَعِنْدَ طَعَامِهِ قَالَ الشَّيْطَانُ لاَ مَبِيتَ لَكُمْ وَلاَ عَشَاءَ وَإِذَا دَخَلَ فَلَمْ يَذْكُرِ اللَّهَ عِنْدَ دُخُولِهِ قَالَ الشَّيْطَانُ أَدْرَكْتُمُ الْمَبِيتَ فَإِذَا لَمْ يَذْكُرِ اللَّهَ عِنْدَ طَعَامِهِ قَالَ أَدْرَكْتُمُ الْمَبِيتَ وَالْعَشَاءَ ‏"‏ ‏.‏\hadithno{3765}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2018)}\hadithtrans{Jabir bin ‘Abd Allah said that he heard the Prophet(ﷺ) say:When a man enters his house and mention Allah’s name on entering and on his food, the devil says: You have no place to spend the night and no evening meal; but when he enters without mentioning Allah’s name on entering, the devil says: You have found a place to spend the night, and when he does not mention Allah’s name at his food, he says: You have found a place to spend the night and an evening meal}}
\hadithdefcmd{abudawud}{3766}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ خَيْثَمَةَ، عَنْ أَبِي حُذَيْفَةَ، عَنْ حُذَيْفَةَ، قَالَ كُنَّا إِذَا حَضَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم طَعَامًا لَمْ يَضَعْ أَحَدُنَا يَدَهُ حَتَّى يَبْدَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِنَّا حَضَرْنَا مَعَهُ طَعَامًا فَجَاءَ أَعْرَابِيٌّ كَأَنَّمَا يُدْفَعُ فَذَهَبَ لِيَضَعَ يَدَهُ فِي الطَّعَامِ فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ ثُمَّ جَاءَتْ جَارِيَةٌ كَأَنَّمَا تُدْفَعُ فَذَهَبَتْ لِتَضَعَ يَدَهَا فِي الطَّعَامِ فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهَا وَقَالَ ‏ "‏ إِنَّ الشَّيْطَانَ لَيَسْتَحِلُّ الطَّعَامَ الَّذِي لَمْ يُذْكَرِ اسْمُ اللَّهِ عَلَيْهِ وَإِنَّهُ جَاءَ بِهَذَا الأَعْرَابِيِّ يَسْتَحِلُّ بِهِ فَأَخَذْتُ بِيَدِهِ وَجَاءَ بِهَذِهِ الْجَارِيَةِ يَسْتَحِلُّ بِهَا فَأَخَذْتُ بِيَدِهَا فَوَالَّذِي نَفْسِي بِيَدِهِ إِنَّ يَدَهُ لَفِي يَدِي مَعَ أَيْدِيهِمَا ‏"‏ ‏.‏\hadithno{3766}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2017)}\hadithtrans{When we were at food with the Messenger of Allah(ﷺ) none of us put in his hand till the Messenger of Allah(ﷺ)put his hand first. Once we were at food with him. A nomad Arab came in as though he were being pushed, and he was about to put his hand in food when the Messenger of Allah (ﷺ) seized him by the hand. Then a girl came in as though she were being pushed, and she was about to put her hand in the food when the Messenger of Allah (ﷺ) seized her by the hand, and he said:The devil considers the food when Allah’s name is not mentioned over it, and he brought his nomad Arab that it might be lawful by means of him, so I seized his hand: then he brought this girl that it might be lawful by means of her, so I seized her hand. By Him in Whose hand my soul is, His hand is in my hand along with their hands}}
\hadithdefcmd{abudawud}{3767}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ هِشَامٍ، - يَعْنِي ابْنَ أَبِي عَبْدِ اللَّهِ الدَّسْتَوَائِيَّ - عَنْ بُدَيْلٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدٍ، عَنِ امْرَأَةٍ، مِنْهُمْ يُقَالُ لَهَا أُمُّ كُلْثُومٍ عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَكَلَ أَحَدُكُمْ فَلْيَذْكُرِ اسْمَ اللَّهِ تَعَالَى فَإِنْ نَسِيَ أَنْ يَذْكُرَ اسْمَ اللَّهِ تَعَالَى فِي أَوَّلِهِ فَلْيَقُلْ بِسْمِ اللَّهِ أَوَّلَهُ وَآخِرَهُ ‏"‏ ‏.‏\hadithno{3767}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: When one of you eats, he should mention Allah's name; if he forgets to mention Allah's name at the beginning, he should say: "In the name of Allah at the beginning and at the end of it}}
\hadithdefcmd{abudawud}{3768}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، حَدَّثَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - حَدَّثَنَا جَابِرُ بْنُ صُبْحٍ، حَدَّثَنَا الْمُثَنَّى بْنُ عَبْدِ الرَّحْمَنِ الْخُزَاعِيُّ، عَنْ عَمِّهِ، أُمَيَّةَ بْنِ مَخْشِيٍّ - وَكَانَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسًا وَرَجُلٌ يَأْكُلُ فَلَمْ يُسَمِّ حَتَّى لَمْ يَبْقَ مِنْ طَعَامِهِ إِلاَّ لُقْمَةٌ فَلَمَّا رَفَعَهَا إِلَى فِيهِ قَالَ بِسْمِ اللَّهِ أَوَّلَهُ وَآخِرَهُ فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ مَا زَالَ الشَّيْطَانُ يَأْكُلُ مَعَهُ فَلَمَّا ذَكَرَ اسْمَ اللَّهِ عَزَّ وَجَلَّ اسْتَقَاءَ مَا فِي بَطْنِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ جَابِرُ بْنُ صُبْحٍ جَدُّ سُلَيْمَانَ بْنِ حَرْبٍ مِنْ قِبَلِ أُمِّهِ ‏.‏\hadithno{3768}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umayyah ibn Makhshi: Umayyah was sitting and a man was eating. He did not mention Allah's name until there remained the last morsel. When he raised it to his mouth, he said: In the name of Allah at the beginning and at the end of it. The Prophet (ﷺ) laughed and said: The devil kept eating along with him, but when he mentioned Allah's name, he vomited what was in his belly. Abu Dawud: Jabir bin Subh is grandfather of Sulaiman bin Harb from his mother's side}}
\hadithdefcmd{abudawud}{3769}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، قَالَ سَمِعْتُ أَبَا جُحَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ آكُلُ مُتَّكِئًا ‏"‏ ‏.‏\hadithno{3769}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3598)}\hadithtrans{Abu Juhaifah reported the Prophet (ﷺ) as sayings:I do not eat while reclining}}
\hadithdefcmd{abudawud}{3770}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ شُعَيْبِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِيهِ، قَالَ مَا رُئِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْكُلُ مُتَّكِئًا قَطُّ وَلاَ يَطَأُ عَقِبَهُ رَجُلاَنِ ‏.‏\hadithno{3770}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) was never seen reclining while eating, nor walking with two men at his heels}}
\hadithdefcmd{abudawud}{3771}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا وَكِيعٌ، عَنْ مُصْعَبِ بْنِ سُلَيْمٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ بَعَثَنِي النَّبِيُّ صلى الله عليه وسلم فَرَجَعْتُ إِلَيْهِ فَوَجَدْتُهُ يَأْكُلُ تَمْرًا وَهُوَ مُقْعٍ ‏.‏\hadithno{3771}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2044)}\hadithtrans{Anas said:The Prophet(ﷺ) sent me(for some work), and when I returned to him found him eating dates and squatting}}
\hadithdefcmd{abudawud}{3772}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَكَلَ أَحَدُكُمْ طَعَامًا فَلاَ يَأْكُلْ مِنْ أَعْلَى الصَّحْفَةِ وَلَكِنْ لِيَأْكُلْ مِنْ أَسْفَلِهَا فَإِنَّ الْبَرَكَةَ تَنْزِلُ مِنْ أَعْلاَهَا ‏"‏ ‏.‏\hadithno{3772}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: When one of you eats, he must not eat from the top of the dish, but should eat from the bottom; for the blessing descends from the top of it}}
\hadithdefcmd{abudawud}{3773}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ الْحِمْصِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عِرْقٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُسْرٍ، قَالَ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم قَصْعَةٌ يُقَالُ لَهَا الْغَرَّاءُ يَحْمِلُهَا أَرْبَعَةُ رِجَالٍ فَلَمَّا أَضْحَوْا وَسَجَدُوا الضُّحَى أُتِيَ بِتِلْكَ الْقَصْعَةِ - يَعْنِي وَقَدْ ثُرِدَ فِيهَا - فَالْتَفُّوا عَلَيْهَا فَلَمَّا كَثُرُوا جَثَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ أَعْرَابِيٌّ مَا هَذِهِ الْجِلْسَةُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ جَعَلَنِي عَبْدًا كَرِيمًا وَلَمْ يَجْعَلْنِي جَبَّارًا عَنِيدًا ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُوا مِنْ حَوَالَيْهَا وَدَعُوا ذِرْوَتَهَا يُبَارَكْ فِيهَا ‏"‏ ‏.‏\hadithno{3773}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Busr: The Prophet (ﷺ) had a bowl called gharra'. It was carried by four persons. When the sun rose high, and they performed the forenoon prayer, the bowl in which tharid was prepared was brought, and the people gathered round it. When they were numerous, the Messenger of Allah (ﷺ) said: Allah has made me a respectable servant, and He did not make me an obstinate tyrant. The Messenger of Allah (ﷺ) said: Eat from it sides and leave its top, the blessing will be conferred on it}}
\hadithdefcmd{abudawud}{3774}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، عَنْ جَعْفَرِ بْنِ بُرْقَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ مَطْعَمَيْنِ عَنِ الْجُلُوسِ عَلَى مَائِدَةٍ يُشْرَبُ عَلَيْهَا الْخَمْرُ وَأَنْ يَأْكُلَ الرَّجُلُ وَهُوَ مُنْبَطِحٌ عَلَى بَطْنِهِ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا الْحَدِيثُ لَمْ يَسْمَعْهُ جَعْفَرٌ مِنَ الزُّهْرِيِّ وَهُوَ مُنْكَرٌ ‏.‏\hadithno{3774}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) forbade two kinds of food: to sit at cloth on which wine is drunk, and to eat by a man while lying on his stomach. Abu Dawud said : Ja'far did not hear this tradition from al-Zuhri. His tradition is rejected}}
\hadithdefcmd{abudawud}{3775}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا جَعْفَرٌ، أَنَّهُ بَلَغَهُ عَنِ الزُّهْرِيِّ، بِهَذَا الْحَدِيثِ ‏.‏\hadithno{3775}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has been transmitted by al-Zuhri from a different chain of narrators}}
\hadithdefcmd{abudawud}{3776}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو بَكْرِ بْنُ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ جَدِّهِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَكَلَ أَحَدُكُمْ فَلْيَأْكُلْ بِيَمِينِهِ وَإِذَا شَرِبَ فَلْيَشْرَبْ بِيَمِينِهِ فَإِنَّ الشَّيْطَانَ يَأْكُلُ بِشِمَالِهِ وَيَشْرَبُ بِشِمَالِهِ ‏"‏ ‏.‏\hadithno{3776}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2020)}\hadithtrans{Ibn ‘Umar reported the Prophet(ﷺ) as sayings:When any of you eats, he should eat with his right hand, and when he drinks, he should drink with his right hand, for the devil eats with his left hand and drinks with his left hand}}
\hadithdefcmd{abudawud}{3777}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، لُوَيْنٌ عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ أَبِي وَجْزَةَ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ادْنُ بُنَىَّ فَسَمِّ اللَّهَ وَكُلْ بِيَمِينِكَ وَكُلْ مِمَّا يَلِيكَ ‏"‏ ‏.‏\hadithno{3777}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umar ibn AbuSalamah: The Prophet (ﷺ) said: Come near, my son, mention Allah's name, eat with your right hand and eat from what is next to you}}
\hadithdefcmd{abudawud}{3778}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو مَعْشَرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقْطَعُوا اللَّحْمَ بِالسِّكِّينِ فَإِنَّهُ مِنْ صَنِيعِ الأَعَاجِمِ وَانْهَسُوهُ فَإِنَّهُ أَهْنَأُ وَأَمْرَأُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَيْسَ هُوَ بِالْقَوِيِّ ‏.‏\hadithno{3778}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: Do not eat meat with a knife, for it is a foreign practice, but bite it, for it is more beneficial and wholesome. Abu Dawud said: This tradition is not strong}}
\hadithdefcmd{abudawud}{3779}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُعَاوِيَةَ، عَنْ عُثْمَانَ بْنِ أَبِي سُلَيْمَانَ، عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، قَالَ كُنْتُ آكُلُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَآخُذُ اللَّحْمَ بِيَدِي مِنَ الْعَظْمِ فَقَالَ ‏ "‏ أَدْنِ الْعَظْمَ مِنْ فِيكَ فَإِنَّهُ أَهْنَأُ وَأَمْرَأُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ عُثْمَانُ لَمْ يَسْمَعْ مِنْ صَفْوَانَ وَهُوَ مُرْسَلٌ ‏.‏\hadithno{3779}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Safwan ibn Umayyah: I was eating with the Prophet (ﷺ) and snatching the meat from the bone with my hand. He said: bring the bone near your mouth, for it is more beneficial and wholesome. Abu Dawud said: 'Uthman did not hear (traditions) from Safwan. This is a mursal tradition}}
\hadithdefcmd{abudawud}{3780}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ زُهَيْرٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعْدِ بْنِ عِيَاضٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ أَحَبَّ الْعُرَاقِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عُرَاقُ الشَّاةِ ‏.‏\hadithno{3780}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The bone dearer to the Messenger of Allah (ﷺ) was the bone of sheep}}
\hadithdefcmd{abudawud}{3781}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، بِهَذَا الإِسْنَادِ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعْجِبُهُ الذِّرَاعُ ‏.‏ قَالَ وَسُمَّ فِي الذِّرَاعِ وَكَانَ يَرَى أَنَّ الْيَهُودَ هُمْ سَمُّوهُ ‏.‏\hadithno{3781}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The tradition mentioned above (No. 3771) has also been narrated by Ibn Mas'ud with a different chain of narrators. This version has: The Prophet (ﷺ) liked the foreleg (of a sheep). Once the foreleg was poisoned, and he thought that the Jews had poisoned it}}
\hadithdefcmd{abudawud}{3782}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ إِنَّ خَيَّاطًا دَعَا رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ صَنَعَهُ - قَالَ أَنَسٌ - فَذَهَبْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى ذَلِكَ الطَّعَامِ فَقَرَّبَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم خُبْزًا مِنْ شَعِيرٍ وَمَرَقًا فِيهِ دُبَّاءٌ وَقَدِيدٌ ‏.‏ قَالَ أَنَسٌ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَتَبَّعُ الدُّبَّاءَ مِنْ حَوَالَىِ الصَّحْفَةِ فَلَمْ أَزَلْ أُحِبُّ الدُّبَّاءَ بَعْدَ يَوْمِئِذٍ ‏.‏\hadithno{3782}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5436) Sahih Muslim (2041)}\hadithtrans{Anas b. Malik said:A tailor invited the Messenger of Allah (ﷺ) to a meal which he had prepared. Anas said: I went along with the Messenger of Allah(ﷺ) barley bread and soup containing pumpkin and dried sliced meat. Anas said: I saw the Messenger of Allah (ﷺ) going after the pumpkin round the dish, so I have always liked pumpkins since that day}}
\hadithdefcmd{abudawud}{3783}{حَدَّثَنَا مُحَمَّدُ بْنُ حَسَّانَ السَّمْتِيُّ، حَدَّثَنَا الْمُبَارَكُ بْنُ سَعِيدٍ، عَنْ عُمَرَ بْنِ سَعِيدٍ، عَنْ رَجُلٍ، مِنْ أَهْلِ الْبَصْرَةِ عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ أَحَبُّ الطَّعَامِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الثَّرِيدَ مِنَ الْخُبْزِ وَالثَّرِيدَ مِنَ الْحَيْسِ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ ضَعِيفٌ ‏.‏\hadithno{3783}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The food the Messenger of Allah (ﷺ) liked best was tharid made from bread and tharid made from Hays. Abu Dawud said: It is a weak (tradition)}}
\hadithdefcmd{abudawud}{3784}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، حَدَّثَنِي قَبِيصَةُ بْنُ هُلْبٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَأَلَهُ رَجُلٌ فَقَالَ إِنَّ مِنَ الطَّعَامِ طَعَامًا أَتَحَرَّجُ مِنْهُ ‏.‏ فَقَالَ ‏ "‏ لاَ يَتَخَلَّجَنَّ فِي صَدْرِكَ شَىْءٌ ضَارَعْتَ فِيهِ النَّصْرَانِيَّةَ ‏"‏ ‏.‏\hadithno{3784}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Qabisah ibn Halb: A man asked the Messenger of Allah (ﷺ): Is there any food from which I should keep myself away? I heard the Messenger of Allah (ﷺ) say: Anything which creates doubt should not occur in your mind by which you resemble Christianity}}
\hadithdefcmd{abudawud}{3785}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ الْجَلاَّلَةِ وَأَلْبَانِهَا ‏.‏\hadithno{3785}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) prohibited eating the animal which feeds on filth and drinking its milk}}
\hadithdefcmd{abudawud}{3786}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنِي أَبُو عَامِرٍ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ لَبَنِ الْجَلاَّلَةِ ‏.‏\hadithno{3786}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) prohibited to drink the milk of the animal which feeds on filth}}
\hadithdefcmd{abudawud}{3787}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي سُرَيْجٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ جَهْمٍ، حَدَّثَنَا عَمْرُو بْنُ أَبِي قَيْسٍ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْجَلاَّلَةِ فِي الإِبِلِ أَنْ يُرْكَبَ عَلَيْهَا أَوْ يُشْرَبَ مِنْ أَلْبَانِهَا ‏.‏\hadithno{3787}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) forbade riding the camel which feeds on filth and drinking its milk}}
\hadithdefcmd{abudawud}{3788}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ عَنْ لُحُومِ الْحُمُرِ وَأَذِنَ لَنَا فِي لُحُومِ الْخَيْلِ ‏.‏\hadithno{3788}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (4219) Sahih Muslim (1941)}\hadithtrans{Jabir b. ‘Abd Allah said:The Messenger of Allah(ﷺ) forbade the flesh of domestic asses on the day of Khaibar, but permitted horse flesh}}
\hadithdefcmd{abudawud}{3789}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ ذَبَحْنَا يَوْمَ خَيْبَرَ الْخَيْلَ وَالْبِغَالَ وَالْحَمِيرَ فَنَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْبِغَالِ وَالْحَمِيرِ وَلَمْ يَنْهَنَا عَنِ الْخَيْلِ ‏.‏\hadithno{3789}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: On the day of Khaybar we slaughtered horses, mules, and assess. The Messenger of Allah (ﷺ) forbade us (to eat) mules and asses, but he did not forbid horse-flesh}}
\hadithdefcmd{abudawud}{3790}{حَدَّثَنَا سَعِيدُ بْنُ شَبِيبٍ، وَحَيْوَةُ بْنُ شُرَيْحٍ الْحِمْصِيُّ، قَالَ حَيْوَةُ حَدَّثَنَا بَقِيَّةُ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ صَالِحِ بْنِ يَحْيَى بْنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ لُحُومِ الْخَيْلِ وَالْبِغَالِ وَالْحَمِيرِ - زَادَ حَيْوَةُ - وَكُلِّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ قَوْلُ مَالِكٍ ‏.‏ قَالَ أَبُو دَاوُدَ لاَ بَأْسَ بِلُحُومِ الْخَيْلِ وَلَيْسَ الْعَمَلُ عَلَيْهِ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا مَنْسُوخٌ قَدْ أَكَلَ لُحُومَ الْخَيْلِ جَمَاعَةٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمُ ابْنُ الزُّبَيْرِ وَفَضَالَةُ بْنُ عُبَيْدٍ وَأَنَسُ بْنُ مَالِكٍ وَأَسْمَاءُ ابْنَةُ أَبِي بَكْرٍ وَسُوَيْدُ بْنُ غَفَلَةَ وَعَلْقَمَةُ وَكَانَتْ قُرَيْشٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم تَذْبَحُهَا ‏.‏\hadithno{3790}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Khalid ibn al-Walid: The Messenger of Allah (ﷺ) forbade us to eat horse-flesh, the flesh of mules and of asses. The narrator Haywah added: Every beast of prey with a fang. Abu Dawud said: This view is held by Malik. Abu Dawud said: There is no harm in (eating) horse-flesh and this tradition is not practised. Abu Dawud said: This tradition has been abrogated. A body of Companions of the Prophet (ﷺ) had eaten horse-flesh. OF them are: Ibn al-Zubair, Fudalah bin 'Ubaid, Anas bin Malik, Asma' daughter of Abu Bakr, Suwaid bin Ghaflah, 'Alqamah; the Quraish used to slaughter them (horses) during the time of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{3791}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنْتُ غُلاَمًا حَزَوَّرًا فَصِدْتُ أَرْنَبًا فَشَوَيْتُهَا فَبَعَثَ مَعِي أَبُو طَلْحَةَ بِعَجُزِهَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَتَيْتُهُ بِهَا فَقَبِلَهَا ‏.‏\hadithno{3791}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2572) Sahih Muslim (1953)}\hadithtrans{Anas b. Malik said:I was an adolescent boy. I hunted a hare and roasted it. Abu Talha sent its hunch through me to the Prophet (ﷺ), so I brought it to him and he accepted it}}
\hadithdefcmd{abudawud}{3792}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ، قَالَ سَمِعْتُ أَبِي خَالِدَ بْنَ الْحُوَيْرِثِ، يَقُولُ إِنَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو كَانَ بِالصِّفَاحِ - قَالَ مُحَمَّدٌ مَكَانٌ بِمَكَّةَ - وَإِنَّ رَجُلاً جَاءَ بِأَرْنَبٍ قَدْ صَادَهَا فَقَالَ يَا عَبْدَ اللَّهِ بْنَ عَمْرٍو مَا تَقُولُ قَالَ قَدْ جِيءَ بِهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا جَالِسٌ فَلَمْ يَأْكُلْهَا وَلَمْ يَنْهَ عَنْ أَكْلِهَا وَزَعَمَ أَنَّهَا تَحِيضُ ‏.‏\hadithno{3792}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Khalid b. al-Huwairith said :‘Abd Allah b. ‘Amar was in al-safah. The narrator Muhammed (b. Khalid) said: it is a place in Mecca. A man brought a hare which he had haunted. He said: ‘Abd Allah b. ‘Amr, what do you say ? He said: It was brought to the Messenger of Allah (ﷺ) when I was sitting (with him). He did not eat it, nor did he prohibit to eat it. He thought that it menstruated}}
\hadithdefcmd{abudawud}{3793}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ خَالَتَهُ، أَهْدَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سَمْنًا وَأَضُبًّا وَأَقِطًا فَأَكَلَ مِنَ السَّمْنِ وَمِنَ الأَقِطِ وَتَرَكَ الأَضُبَّ تَقَذُّرًا وَأُكِلَ عَلَى مَائِدَتِهِ وَلَوْ كَانَ حَرَامًا مَا أُكِلَ عَلَى مَائِدَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3793}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2575) Sahih Muslim (1947)}\hadithtrans{Ibn ‘Abbas said that his maternal aunt presented to the Messenger of Allah (ﷺ) clarified butter, lizards and cottage cheese. He ate from clarified butter and cheese, but left the lizard abominably. It was eaten on the food cloth of the Messenger of Allah (ﷺ). Had it been unlawful, it would not have been eaten on the food cloth of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{3794}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، أَنَّهُ دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَيْتَ مَيْمُونَةَ فَأُتِيَ بِضَبٍّ مَحْنُوذٍ فَأَهْوَى إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ فَقَالَ بَعْضُ النِّسْوَةِ اللاَّتِي فِي بَيْتِ مَيْمُونَةَ أَخْبِرُوا النَّبِيَّ صلى الله عليه وسلم بِمَا يُرِيدُ أَنْ يَأْكُلَ مِنْهُ فَقَالُوا هُوَ ضَبٌّ ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ ‏.‏ قَالَ فَقُلْتُ أَحَرَامٌ هُوَ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ لاَ وَلَكِنَّهُ لَمْ يَكُنْ بِأَرْضِ قَوْمِي فَأَجِدُنِي أَعَافُهُ ‏"‏ ‏.‏ قَالَ خَالِدٌ فَاجْتَرَرْتُهُ فَأَكَلْتُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَنْظُرُ ‏.‏\hadithno{3794}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2537) Sahih Muslim (1945)}\hadithtrans{Ibn ‘Abbas said on the authority of Khalid b. al-Walid that he entered the house of Maimunah along with the Messenger of Allah (ﷺ). A roasted lizard was offered to him. The Messenger of Allah (ﷺ) stretched his hand for it. Some of the women is going to eat. They said:It is a lizard. The Messenger of Allah (ﷺ) raised his hand. I (Khalid) asked: Is it forbidden, Messenger of Allah? He replied, No, but it is not found in the land of my people, so I find it distasteful. Khalid said: I then pulled it and ate it while The Messenger of Allah (ﷺ) was seeing}}
\hadithdefcmd{abudawud}{3795}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا خَالِدٌ، عَنْ حُصَيْنٍ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ ثَابِتِ بْنِ وَدِيعَةَ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي جَيْشٍ فَأَصَبْنَا ضِبَابًا - قَالَ - فَشَوَيْتُ مِنْهَا ضَبًّا فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَوَضَعْتُهُ بَيْنَ يَدَيْهِ - قَالَ - فَأَخَذَ عُودًا فَعَدَّ بِهِ أَصَابِعَهُ ثُمَّ قَالَ ‏ "‏ إِنَّ أُمَّةً مِنْ بَنِي إِسْرَائِيلَ مُسِخَتْ دَوَابَّ فِي الأَرْضِ وَإِنِّي لاَ أَدْرِي أَىُّ الدَّوَابِّ هِيَ ‏"‏ ‏.‏ قَالَ فَلَمْ يَأْكُلْ وَلَمْ يَنْهَ ‏.‏\hadithno{3795}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Thabit ibn Wadi'ah: We were in an army with the Messenger of Allah (ﷺ). We got some lizards. I roasted one lizard and brought it to the Messenger of Allah (ﷺ) and placed it before him. He took a stick and counted its fingers. He then said: A group from the children of Isra'il was transformed into an animal of the land, and I do not know which animal it was. He did not eat it nor did he forbid (its eating)}}
\hadithdefcmd{abudawud}{3796}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، أَنَّ الْحَكَمَ بْنَ نَافِعٍ، حَدَّثَهُمْ حَدَّثَنَا ابْنُ عَيَّاشٍ، عَنْ ضَمْضَمِ بْنِ زُرْعَةَ، عَنْ شُرَيْحِ بْنِ عُبَيْدٍ، عَنْ أَبِي رَاشِدٍ الْحُبْرَانِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ شِبْلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ لَحْمِ الضَّبِّ ‏.‏\hadithno{3796}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbdurRahman ibn Shibl: The Messenger of Allah (ﷺ) forbade to eat the flesh of lizard}}
\hadithdefcmd{abudawud}{3797}{حَدَّثَنَا الْفَضْلُ بْنُ سَهْلٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ مَهْدِيٍّ، حَدَّثَنِي بُرَيْهُ بْنُ عُمَرَ بْنِ سَفِينَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ أَكَلْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَحْمَ حُبَارَى ‏.‏\hadithno{3797}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Safinah: I ate the flesh of a bustard along with the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3798}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا غَالِبُ بْنُ حَجْرَةَ، حَدَّثَنِي مِلْقَامُ بْنُ تَلِبٍّ، عَنْ أَبِيهِ، قَالَ صَحِبْتُ النَّبِيَّ صلى الله عليه وسلم فَلَمْ أَسْمَعْ لِحَشَرَةِ الأَرْضِ تَحْرِيمًا ‏.‏\hadithno{3798}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated at-Talabb ibn Tha'labah at-Tamimi: I accompanied the Messenger of Allah (ﷺ), but I did not hear about the prohibition of (eating) insects and little creatures of land}}
\hadithdefcmd{abudawud}{3799}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ خَالِدٍ الْكَلْبِيُّ أَبُو ثَوْرٍ، حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عِيسَى بْنِ نُمَيْلَةَ، عَنْ أَبِيهِ، قَالَ كُنْتُ عِنْدَ ابْنِ عُمَرَ فَسُئِلَ عَنْ أَكْلِ الْقُنْفُذِ، فَتَلاَ ‏\{‏ قُلْ لاَ أَجِدُ فِيمَا أُوحِيَ إِلَىَّ مُحَرَّمًا ‏\}‏ الآيَةَ قَالَ قَالَ شَيْخٌ عِنْدَهُ سَمِعْتُ أَبَا هُرَيْرَةَ يَقُولُ ذُكِرَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ خَبِيثَةٌ مِنَ الْخَبَائِثِ ‏"‏ ‏.‏ فَقَالَ ابْنُ عُمَرَ إِنْ كَانَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم هَذَا فَهُوَ كَمَا قَالَ مَا لَمْ نَدْرِ ‏.‏\hadithno{3799}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: Numaylah said: I was with Ibn Umar. He was asked about eating hedgehog. He recited: "Say: I find not in the message received by me by inspiration any (meat) forbidden." An old man who was with him said: I heard AbuHurayrah say: It was mentioned to the Messenger of Allah (ﷺ). Noxious of the noxious. Ibn Umar said: If the Messenger of Allah (ﷺ) had said it, it is as he said that we did not know}}
\hadithdefcmd{abudawud}{3800}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ صُبَيْحٍ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ شَرِيكٍ الْمَكِّيَّ - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ أَهْلُ الْجَاهِلِيَّةِ يَأْكُلُونَ أَشْيَاءَ وَيَتْرُكُونَ أَشْيَاءَ تَقَذُّرًا فَبَعَثَ اللَّهُ تَعَالَى نَبِيَّهُ وَأَنْزَلَ كِتَابَهُ وَأَحَلَّ حَلاَلَهُ وَحَرَّمَ حَرَامَهُ فَمَا أَحَلَّ فَهُوَ حَلاَلٌ وَمَا حَرَّمَ فَهُوَ حَرَامٌ وَمَا سَكَتَ عَنْهُ فَهُوَ عَفْوٌ وَتَلاَ ‏\{‏ قُلْ لاَ أَجِدُ فِيمَا أُوحِيَ إِلَىَّ مُحَرَّمًا ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{3800}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The people of pre-Islamic times used to eat some things and leave others alone, considering them unclean. Then Allah sent His Prophet (ﷺ) and sent down His Book, marking some things lawful and others unlawful; so what He made lawful is lawful, what he made unlawful is unlawful, and what he said nothing about is allowable. And he recited: "Say: I find not in the message received by me by inspiration any (meat) forbidden to be eaten by one who wishes to eat it...." up to the end of the verse}}
\hadithdefcmd{abudawud}{3801}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمَّارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الضَّبُعِ فَقَالَ ‏ "‏ هُوَ صَيْدٌ وَيُجْعَلُ فِيهِ كَبْشٌ إِذَا صَادَهُ الْمُحْرِمُ ‏"‏ ‏.‏\hadithno{3801}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: I asked the Messenger of Allah (ﷺ) about the hyena. He replied: It is game, and if one who is wearing ihram (pilgrim's robe) hunts it, he should give a sheep as atonement}}
\hadithdefcmd{abudawud}{3802}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السَّبُعِ ‏.‏\hadithno{3802}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5530) Sahih Muslim (1932)}\hadithtrans{Abu Tha’labah al-Khushani said:The Messenger of Allah (ﷺ) prohibited eating fanged beasts of prey}}
\hadithdefcmd{abudawud}{3803}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السَّبُعِ وَعَنْ كُلِّ ذِي مِخْلَبٍ مِنَ الطَّيْرِ ‏.‏\hadithno{3803}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1934)}\hadithtrans{Ibn ‘Abbas said:The Messenger of Allah(ﷺ) prohibited the eating of every beast of prey with fang, and every bird with a talon}}
\hadithdefcmd{abudawud}{3804}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنْ مَرْوَانَ بْنِ رُؤْبَةَ التَّغْلِبِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَوْفٍ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ لاَ يَحِلُّ ذُو نَابٍ مِنَ السِّبَاعِ وَلاَ الْحِمَارُ الأَهْلِيُّ وَلاَ اللُّقَطَةُ مِنْ مَالِ مُعَاهِدٍ إِلاَّ أَنْ يَسْتَغْنِيَ عَنْهَا وَأَيُّمَا رَجُلٍ ضَافَ قَوْمًا فَلَمْ يَقْرُوهُ فَإِنَّ لَهُ أَنْ يُعْقِبَهُمْ بِمِثْلِ قِرَاهُ ‏"‏ ‏.‏\hadithno{3804}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Miqdam ibn Ma'dikarib: The Prophet (ﷺ) said: Beware, the fanged beast of prey is not lawful, nor the domestic asses, nor the find from the property of a man with whom treaty has been concluded, except that he did not need it. If anyone is a guest of people who provide no hospitality for him, he is entitled to take from them the equivalent of the hospitality due to him}}
\hadithdefcmd{abudawud}{3805}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنِ ابْنِ أَبِي عَدِيٍّ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ عَلِيِّ بْنِ الْحَكَمِ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ وَعَنْ كُلِّ ذِي مِخْلَبٍ مِنَ الطَّيْرِ ‏.‏\hadithno{3805}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: On the day of Khaybar the Messenger of Allah (ﷺ) prohibited eating every beast of prey, and every bird with a talon}}
\hadithdefcmd{abudawud}{3806}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنِي أَبُو سَلَمَةَ، سُلَيْمَانُ بْنُ سُلَيْمٍ عَنْ صَالِحِ بْنِ يَحْيَى بْنِ الْمِقْدَامِ، عَنْ جَدِّهِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، قَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم خَيْبَرَ فَأَتَتِ الْيَهُودُ فَشَكَوْا أَنَّ النَّاسَ قَدْ أَسْرَعُوا إِلَى حَظَائِرِهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ لاَ تَحِلُّ أَمْوَالُ الْمُعَاهِدِينَ إِلاَّ بِحَقِّهَا وَحَرَامٌ عَلَيْكُمْ حُمُرُ الأَهْلِيَّةِ وَخَيْلُهَا وَبِغَالُهَا وَكُلُّ ذِي نَابٍ مِنَ السِّبَاعِ وَكُلُّ ذِي مِخْلَبٍ مِنَ الطَّيْرِ ‏"‏ ‏.‏\hadithno{3806}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Khalid ibn al-Walid: I went with the Messenger of Allah (ﷺ) to fight at the battle of Khaybar, and the Jews came and complained that the people had hastened to take their protected property (as a booty), so the Messenger of Allah (ﷺ) said: The property of those who have been given a mules, every fanged beast of prey, and every bird with a talon are forbidden for you}}
\hadithdefcmd{abudawud}{3807}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ عُمَرَ بْنِ زَيْدٍ الصَّنْعَانِيِّ، أَنَّهُ سَمِعَ أَبَا الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الْهِرِّ ‏.‏ قَالَ ابْنُ عَبْدِ الْمَلِكِ عَنْ أَكْلِ الْهِرِّ وَأَكْلِ ثَمَنِهَا ‏.‏\hadithno{3807}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: that the Prophet (ﷺ) forbade payment for a cat. Ibn AbdulMalik said: to eat a cat and to enjoy its price}}
\hadithdefcmd{abudawud}{3808}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَسَنٍ الْمِصِّيصِيُّ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَخْبَرَنِي رَجُلٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ عَنْ أَنْ نَأْكُلَ لُحُومَ الْحُمُرِ وَأَمَرَنَا أَنْ نَأْكُلَ لُحُومَ الْخَيْلِ قَالَ عَمْرٌو فَأَخْبَرْتُ هَذَا الْخَبَرَ أَبَا الشَّعْثَاءِ فَقَالَ قَدْ كَانَ الْحَكَمُ الْغِفَارِيُّ فِينَا يَقُولُ هَذَا وَأَبَى ذَلِكَ الْبَحْرُ يُرِيدُ ابْنَ عَبَّاسٍ ‏.‏\hadithno{3808}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir b. ‘Abd Allah said:On the day of Khaibar the Messenger of Allah(ﷺ) forbade us to eat the flesh of domestic asses, and ordered us to eat horse-flesh. ‘Amr said: I informed Abu al-Sha’tha’ about this tradition. He said: Al-Hakam al-Ghifari among us said this, and the” ocean” denied that, intending thereby Ibn’ Abbas}}
\hadithdefcmd{abudawud}{3809}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ مَنْصُورٍ، عَنْ عُبَيْدٍ أَبِي الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ غَالِبِ بْنِ أَبْجَرَ، قَالَ أَصَابَتْنَا سَنَةٌ فَلَمْ يَكُنْ فِي مَالِي شَىْءٌ أُطْعِمُ أَهْلِي إِلاَّ شَىْءٌ مِنْ حُمُرٍ وَقَدْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَرَّمَ لُحُومَ الْحُمُرِ الأَهْلِيَّةِ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ أَصَابَتْنَا السَّنَةُ وَلَمْ يَكُنْ فِي مَالِي مَا أُطْعِمُ أَهْلِي إِلاَّ سِمَانُ الْحُمُرِ وَإِنَّكَ حَرَّمْتَ لُحُومَ الْحُمُرِ الأَهْلِيَّةِ ‏.‏ فَقَالَ ‏ "‏ أَطْعِمْ أَهْلَكَ مِنْ سَمِينِ حُمُرِكَ فَإِنَّمَا حَرَّمْتُهَا مِنْ أَجْلِ جَوَالِّ الْقَرْيَةِ ‏"‏ ‏.‏ يَعْنِي الْجَلاَّلَةَ ‏.‏ قَالَ أَبُو دَاوُدَ عَبْدُ الرَّحْمَنِ هَذَا هُوَ ابْنُ مَعْقِلٍ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ عُبَيْدٍ أَبِي الْحَسَنِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَعْقِلٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ بِشْرٍ عَنْ نَاسٍ مِنْ مُزَيْنَةَ أَنَّ سَيِّدَ مُزَيْنَةَ أَبْجَرَ أَوِ ابْنَ أَبْجَرَ سَأَلَ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{3809}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ghalib ibn Abjar: We faced a famine, and I had nothing from my property which I could feed my family ex except a few asses, and the Prophet (ﷺ) forbade the flesh of domestic asses. So I came to the Prophet (ﷺ) and said: Messenger of Allah (may peace be upon) , we are suffering from famine, and I have no property which I feed my family except some fat asses, and you have forbidden the flesh of domestic asses. He said: Feed your family on the fat asses of yours, for I forbade them on account of the animal which feeds on the filth of the town, that is, the animal which feeds on filth. Abu Dawud said: This 'Abd al-Rahman is Ibn Ma'qil. Abu Dawud said: Suh'bah transmitted this tradition from 'Ubaid Abi al-Hasan, from 'Abd al-Rahman bin Maq'il, from'Abd al-Rahman bin Bishr, from some people of Muzainah stating that Abjar, the chief of Muzainah, or Ibn Abjar asked the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3810}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ مِسْعَرٍ، عَنِ ابْنِ عُبَيْدٍ، عَنِ ابْنِ مَعْقِلٍ، عَنْ رَجُلَيْنِ، مِنْ مُزَيْنَةَ أَحَدُهُمَا عَنِ الآخَرِ، أَحَدُهُمَا عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ عُوَيْمٍ وَالآخَرُ غَالِبُ بْنُ الأَبْجَرِ ‏.‏ قَالَ مِسْعَرٌ أَرَى غَالِبًا الَّذِي أَتَى النَّبِيَّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏\hadithno{3810}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muhammed b. Sulaiman narrated from Abu Nu’aim, from Mis’ar, from Ibn ‘Ubaid, from Ibn Ma’qil, from two men of Muzainah, one from the other, one of them is ‘Abd Allah b. ‘Amr b. ‘Uwaim, and the other is Ghalib b. al-Abjar. Mis’ar said:I think it was Ghalib who had come to the Prophet(ﷺ) with tradition}}
\hadithdefcmd{abudawud}{3811}{حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، حَدَّثَنَا وُهَيْبٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ وَعَنِ الْجَلاَّلَةِ عَنْ رُكُوبِهَا وَأَكْلِ لَحْمِهَا ‏.‏\hadithno{3811}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: On the day of Khaybar the Messenger of Allah (may pease be upon him) forbade (eating) the flesh of domestic asses, and the animal which feeds on filth: riding it and eating its flesh}}
\hadithdefcmd{abudawud}{3812}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي يَعْفُورٍ، قَالَ سَمِعْتُ ابْنَ أَبِي أَوْفَى، وَسَأَلْتُهُ، عَنِ الْجَرَادِ، فَقَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سِتَّ أَوْ سَبْعَ غَزَوَاتٍ فَكُنَّا نَأْكُلُهُ مَعَهُ ‏.‏\hadithno{3812}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5495) Sahih Muslim (1952)}\hadithtrans{Abu Ya’fur said:I heard Ibn Abi Awfa say when I asked him about (eating) locusts: I went on six or seven expeditions along with the Messenger of Allah (ﷺ) and we ate them (locusts) along with him}}
\hadithdefcmd{abudawud}{3813}{حَدَّثَنَا مُحَمَّدُ بْنُ الْفَرَجِ الْبَغْدَادِيُّ، حَدَّثَنَا ابْنُ الزِّبْرِقَانِ، حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ سَلْمَانَ، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الْجَرَادِ فَقَالَ ‏ "‏ أَكْثَرُ جُنُودِ اللَّهِ لاَ آكُلُهُ وَلاَ أُحَرِّمُهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الْمُعْتَمِرُ عَنْ أَبِيهِ عَنْ أَبِي عُثْمَانَ عَنِ النَّبِيِّ صلى الله عليه وسلم لَمْ يَذْكُرْ سَلْمَانَ ‏.‏\hadithno{3813}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salman al-Farsi: The Messenger of Allah (ﷺ) was asked about (eating) locusts. He replied: They are the most numerous of Allah's hosts. I neither eat them nor declare them unlawful}}
\hadithdefcmd{abudawud}{3814}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَعَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِي الْعَوَّامِ الْجَزَّارِ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ سَلْمَانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ فَقَالَ مِثْلَهُ فَقَالَ ‏ "‏ أَكْثَرُ جُنْدِ اللَّهِ ‏"‏ ‏.‏ قَالَ عَلِيٌّ اسْمُهُ فَائِدٌ يَعْنِي أَبَا الْعَوَّامِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ حَمَّادُ بْنُ سَلَمَةَ عَنْ أَبِي الْعَوَّامِ عَنْ أَبِي عُثْمَانَ عَنِ النَّبِيِّ صلى الله عليه وسلم لَمْ يَذْكُرْ سَلْمَانَ ‏.‏\hadithno{3814}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Salman through a different chain of narrators. This version goes:Salman said: The Messenger of Allah(ﷺ) was asked about locusts. He replied in a similar way(as mentioned above) saying: The most numerous of Allah’s host. The narrator ‘Ali said: His name is Fa’id, that is the name of al-Awwam. Abu Dawud said: This tradition has been transmitted by Hammad b. Salamah, from Abu al-Awwam from Abu uthman, from the Prophet (ﷺ). He did not mention salman (i.e., the companions)}}
\hadithdefcmd{abudawud}{3815}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أُمَيَّةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَلْقَى الْبَحْرُ أَوْ جَزَرَ عَنْهُ فَكُلُوهُ وَمَا مَاتَ فِيهِ وَطَفَا فَلاَ تَأْكُلُوهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ سُفْيَانُ الثَّوْرِيُّ وَأَيُّوبُ وَحَمَّادٌ عَنْ أَبِي الزُّبَيْرِ أَوْقَفُوهُ عَلَى جَابِرٍ وَقَدْ أُسْنِدَ هَذَا الْحَدِيثُ أَيْضًا مِنْ وَجْهٍ ضَعِيفٍ عَنِ ابْنِ أَبِي ذِئْبٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3815}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: What the sea throws up and is left by the tide you may eat, but what dies in the sea and floats you must not eat. Abu Dawud said: This tradition has been transmitted by Sufyan al-Thawri, Ayyub and Hammad from Abu al-Zubair as the statement of Jabor himself (and not from the Prophet). It has been also transmitted direct from the Prophet (ﷺ) through a weak chain by Abu Dhi'b, from Abu al-Zubair on the authority if Jabir from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3816}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ رَجُلاً، نَزَلَ الْحَرَّةَ وَمَعَهُ أَهْلُهُ وَوَلَدُهُ فَقَالَ رَجُلٌ إِنَّ نَاقَةً لِي ضَلَّتْ فَإِنْ وَجَدْتَهَا فَأَمْسِكْهَا ‏.‏ فَوَجَدَهَا فَلَمْ يَجِدْ صَاحِبَهَا فَمَرِضَتْ فَقَالَتِ امْرَأَتُهُ انْحَرْهَا ‏.‏ فَأَبَى فَنَفَقَتْ فَقَالَتِ اسْلُخْهَا حَتَّى نُقَدِّدَ شَحْمَهَا وَلَحْمَهَا وَنَأْكُلَهُ ‏.‏ فَقَالَ حَتَّى أَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَتَاهُ فَسَأَلَهُ فَقَالَ ‏"‏ هَلْ عِنْدَكَ غِنًى يُغْنِيكَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَكُلُوهَا ‏"‏ ‏.‏ قَالَ فَجَاءَ صَاحِبُهَا فَأَخْبَرَهُ الْخَبَرَ فَقَالَ ‏"‏ هَلاَّ كُنْتَ نَحَرْتَهَا ‏"‏ ‏.‏ قَالَ اسْتَحْيَيْتُ مِنْكَ ‏.‏\hadithno{3816}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Samurah: A man alighted at Harrah with his wife and children. A man said (to him): My she-camel has strayed; if you find it, detain it. He found it, but did not find its owner, and it fell ill. His wife said: Slaughter it. But he refused and it died. She said: Skin it so that we may dry its fat and flesh and then eat them. He said: Let me ask the Messenger of Allah (ﷺ). So he came to him (the Prophet) and asked him. He said: Have you sufficient for your needs? He replied: No. He then said: Then eat it. Then its owner came and he told him the story. He said: Why did you not slaughter it? He replied: I was ashamed (or afraid) of you}}
\hadithdefcmd{abudawud}{3817}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا عُقْبَةُ بْنُ وَهْبِ بْنِ عُقْبَةَ الْعَامِرِيُّ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنِ الْفُجَيْعِ الْعَامِرِيِّ، أَنَّهُ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ مَا يَحِلُّ لَنَا مِنَ الْمَيْتَةِ قَالَ ‏"‏ مَا طَعَامُكُمْ ‏"‏ ‏.‏ قُلْنَا نَغْتَبِقُ وَنَصْطَبِحُ ‏.‏ قَالَ أَبُو نُعَيْمٍ فَسَّرَهُ لِي عُقْبَةُ قَدَحٌ غُدْوَةً وَقَدَحٌ عَشِيَّةً ‏.‏ قَالَ ‏"‏ ذَاكَ - وَأَبِي - الْجُوعُ ‏"‏ ‏.‏ فَأَحَلَّ لَهُمُ الْمَيْتَةَ عَلَى هَذِهِ الْحَالِ ‏.‏ قَالَ أَبُو دَاوُدَ الْغَبُوقُ مِنْ آخِرِ النَّهَارِ وَالصَّبُوحُ مِنْ أَوَّلِ النَّهَارِ ‏.‏\hadithno{3817}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Faji' ibn Abdullah al-Amiri: Al-Faji' came to the Messenger of Allah (ﷺ) and asked: Is not dead meat lawful for us? He said: What is your food? We said: Some food in the evening and some in the morning. AbuNu'aym said: Uqbah explained it to me saying: a cup (of milk) in the morning and a cup in the evening; this does not satisfy the hunger. So made the carrion lawful for them in this condition. Abu Dawud said: Ghabuq is a drink in the evening and Sabuh is a drink in the morning}}
\hadithdefcmd{abudawud}{3818}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ حُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَدِدْتُ أَنَّ عِنْدِي خُبْزَةً بَيْضَاءَ مِنْ بُرَّةٍ سَمْرَاءَ مُلَبَّقَةً بِسَمْنٍ وَلَبَنٍ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ مِنَ الْقَوْمِ فَاتَّخَذَهُ فَجَاءَ بِهِ فَقَالَ ‏"‏ فِي أَىِّ شَىْءٍ كَانَ هَذَا ‏"‏ ‏.‏ قَالَ فِي عُكَّةِ ضَبٍّ قَالَ ‏"‏ ارْفَعْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا حَدِيثٌ مُنْكَرٌ ‏.‏ قَالَ أَبُو دَاوُدَ وَأَيُّوبُ لَيْسَ هُوَ السَّخْتِيَانِيَّ ‏.‏\hadithno{3818}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: I wish I had a white loaf made from tawny and softened with clarified butter and milk. A man from among the people got up and getting one brought it. He asked: In which had it been? He replied: In a lizard skin. He said: Take it away. Abu Dawud said: This is a munkar (rejected) tradition. Abu Dawud said: Ayyub, the narrator of this tradition, is not (Ayyub) al-Sakhtiyani}}
\hadithdefcmd{abudawud}{3819}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عُمَرَ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِجُبْنَةٍ فِي تَبُوكَ فَدَعَا بِسِكِّينٍ فَسَمَّى وَقَطَعَ ‏.‏\hadithno{3819}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) was brought a piece of cheese in Tabuk. He called for a knife, mentioned Allah's name and cut it}}
\hadithdefcmd{abudawud}{3820}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نِعْمَ الإِدَامُ الْخَلُّ ‏"‏ ‏.‏\hadithno{3820}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir reported the Prophet (ﷺ) as saying:What a good condiment vinegar is}}
\hadithdefcmd{abudawud}{3821}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا الْمُثَنَّى بْنُ سَعِيدٍ، عَنْ طَلْحَةَ بْنِ نَافِعٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نِعْمَ الإِدَامُ الْخَلُّ ‏"‏ ‏.‏\hadithno{3821}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2052)}\hadithtrans{Jabir b. ‘Abd Allah reported the Prophet (ﷺ) as sayings:What a good condiment vinegar is}}
\hadithdefcmd{abudawud}{3822}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَكَلَ ثُومًا أَوْ بَصَلاً فَلْيَعْتَزِلْنَا - أَوْ لِيَعْتَزِلْ مَسْجِدَنَا - وَلْيَقْعُدْ فِي بَيْتِهِ ‏"‏ ‏.‏ وَإِنَّهُ أُتِيَ بِبَدْرٍ فِيهِ خَضِرَاتٌ مِنَ الْبُقُولِ فَوَجَدَ لَهَا رِيحًا فَسَأَلَ فَأُخْبِرَ بِمَا فِيهَا مِنَ الْبُقُولِ فَقَالَ ‏"‏ قَرِّبُوهَا ‏"‏ ‏.‏ إِلَى بَعْضِ أَصْحَابِهِ كَانَ مَعَهُ فَلَمَّا رَآهُ كَرِهَ أَكْلَهَا قَالَ ‏"‏ كُلْ فَإِنِّي أُنَاجِي مَنْ لاَ تُنَاجِي ‏"‏ ‏.‏ قَالَ أَحْمَدُ بْنُ صَالِحٍ بِبَدْرٍ فَسَّرَهُ ابْنُ وَهْبٍ طَبَقٌ\hadithno{3822}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (855) Sahih Muslim (564)}\hadithtrans{Jabir b. ‘Abd Allah reported the Messenger of Allah (ﷺ) as sayings:He who eats garlic or onion must keep away from us. Or he said: must keep away from our mosque or must sit in his house. A dish containing green vegetables was brought to him, and noticing that it had an odour he asked (about it). He was told that it contained some vegetables. He then said: Bring it near, to one of his companion who was with him. When he saw it, he abominated eating it, and said: eat for I hold intimate converse with one with whom you do not. Ahmad b. Salih said: Ibn Wahb explained the word badr as meaning dish}}
\hadithdefcmd{abudawud}{3823}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ بَكْرَ بْنَ سَوَادَةَ، حَدَّثَهُ أَنَّ أَبَا النَّجِيبِ مَوْلَى عَبْدِ اللَّهِ بْنِ سَعْدٍ حَدَّثَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ حَدَّثَهُ أَنَّهُ، ذُكِرَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم الثُّومُ وَالْبَصَلُ قِيلَ يَا رَسُولَ اللَّهِ وَأَشَدُّ ذَلِكَ كُلِّهِ الثُّومُ أَفَتُحَرِّمُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كُلُوهُ وَمَنْ أَكَلَهُ مِنْكُمْ فَلاَ يَقْرَبْ هَذَا الْمَسْجِدَ حَتَّى يَذْهَبَ رِيحُهُ مِنْهُ ‏"‏ ‏.‏\hadithno{3823}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: The garlic and onions were mentioned before the Messenger of Allah (ﷺ). He was told: The most severe of them is garlic. Would you make it unlawful? The Prophet (ﷺ) said: Eat it, and he who eats it should not come near this mosque until its odour goes away}}
\hadithdefcmd{abudawud}{3824}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الشَّيْبَانِيِّ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ حُذَيْفَةَ، أَظُنُّهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَفَلَ تِجَاهَ الْقِبْلَةِ جَاءَ يَوْمَ الْقِيَامَةِ تَفْلُهُ بَيْنَ عَيْنَيْهِ وَمَنْ أَكَلَ مِنْ هَذِهِ الْبَقْلَةِ الْخَبِيثَةِ فَلاَ يَقْرَبَنَّ مَسْجِدَنَا ‏"‏ ‏.‏ ثَلاَثًا ‏.‏\hadithno{3824}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hudhayfah ibn al-Yaman: Zirr ibn Hubaysh said: Hudhayfah traced, I think, to the Messenger of Allah (ﷺ) the saying: He who spits in the direction of the qiblah will come on the Day of Resurrection in the state that his saliva will be between his eyes; and he who eats from this noxious vegetable should not come near our mosque, saying it three times}}
\hadithdefcmd{abudawud}{3825}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ فَلاَ يَقْرَبَنَّ الْمَسَاجِدَ ‏"‏ ‏.‏\hadithno{3825}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (853) Sahih Muslim (561)}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: He who eats from this plant should not come near the mosques}}
\hadithdefcmd{abudawud}{3826}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو هِلاَلٍ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ أَكَلْتُ ثُومًا فَأَتَيْتُ مُصَلَّى النَّبِيِّ صلى الله عليه وسلم وَقَدْ سُبِقْتُ بِرَكْعَةٍ فَلَمَّا دَخَلْتُ الْمَسْجِدَ وَجَدَ النَّبِيُّ صلى الله عليه وسلم رِيحَ الثُّومِ فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَتَهُ قَالَ ‏"‏ مَنْ أَكَلَ مِنْ هَذِهِ الشَّجَرَةِ فَلاَ يَقْرَبْنَا حَتَّى يَذْهَبَ رِيحُهَا ‏"‏ ‏.‏ أَوْ ‏"‏ رِيحُهُ ‏"‏ ‏.‏ فَلَمَّا قَضَيْتُ الصَّلاَةَ جِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ وَاللَّهِ لَتُعْطِيَنِّي يَدَكَ ‏.‏ قَالَ فَأَدْخَلْتُ يَدَهُ فِي كُمِّ قَمِيصِي إِلَى صَدْرِي فَإِذَا أَنَا مَعْصُوبُ الصَّدْرِ قَالَ ‏"‏ إِنَّ لَكَ عُذْرًا ‏"‏ ‏.‏\hadithno{3826}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Mughirah ibn Shu'bah: I ate garlic and came to the place where the Prophet (ﷺ) was praying; one rak'ah of prayer had been performed when I joined. When I entered the mosque, the Prophet (ﷺ) noticed the odour of garlic. When the Messenger of Allah (ﷺ) finished his prayer, he said: He who eats from this plant should not come near us until its odour has gone away. When I finished the prayer, I came to the Messenger of Allah (ﷺ) and said: Messenger of Allah, do give me your hand. Then I put his hand in the sleeve of my shirt, carrying it to my chest to show that my chest was fastened with a belt. He said: You have a (valid) excuse}}
\hadithdefcmd{abudawud}{3827}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا خَالِدُ بْنُ مَيْسَرَةَ، - يَعْنِي الْعَطَّارَ - عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ هَاتَيْنِ الشَّجَرَتَيْنِ وَقَالَ ‏"‏ مَنْ أَكَلَهُمَا فَلاَ يَقْرَبَنَّ مَسْجِدَنَا ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِنْ كُنْتُمْ لاَ بُدَّ آكِلِيهِمَا فَأَمِيتُوهُمَا طَبْخًا ‏"‏ ‏.‏ قَالَ يَعْنِي الْبَصَلَ وَالثُّومَ ‏.‏\hadithno{3827}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu'awiyah ibn Qurrah: The Messenger of Allah (ﷺ) forbade these two plants (i.e. garlic and onions), and he said: He who eats them should not come near our mosque. If it is necessary to eat them, make them dead by cooking, that is, onions and garlic}}
\hadithdefcmd{abudawud}{3828}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْجَرَّاحُ أَبُو وَكِيعٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ شَرِيكٍ، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ قَالَ نُهِيَ عَنْ أَكْلِ الثُّومِ، إِلاَّ مَطْبُوخًا ‏.‏ قَالَ أَبُو دَاوُدَ شَرِيكُ بْنُ حَنْبَلٍ ‏.‏\hadithno{3828}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: It is forbidden to eat garlic unless it is cooked. Abu Dawud said: The full name of the narrator Sharik is Sharik bin Hanbal}}
\hadithdefcmd{abudawud}{3829}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا ح، وَحَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدٍ، عَنْ أَبِي زِيَادٍ، خِيَارِ بْنِ سَلَمَةَ أَنَّهُ سَأَلَ عَائِشَةَ عَنِ الْبَصَلِ، فَقَالَتْ إِنَّ آخِرَ طَعَامٍ أَكَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم طَعَامٌ فِيهِ بَصَلٌ ‏.‏\hadithno{3829}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Khalid said: AbuZiyad Khiyar ibn Salamah asked Aisha about onions. She replied: The last food which the Messenger of Allah (ﷺ) ate was some which contained onions}}
\hadithdefcmd{abudawud}{3830}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ أَبِي يَحْيَى، عَنْ يَزِيدَ الأَعْوَرِ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم أَخَذَ كِسْرَةً مِنْ خُبْزِ شَعِيرٍ فَوَضَعَ عَلَيْهَا تَمْرَةً وَقَالَ ‏ "‏ هَذِهِ إِدَامُ هَذِهِ ‏"‏ ‏.‏\hadithno{3830}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Yusuf ibn Abdullah ibn Salam: I saw that the Prophet (ﷺ) took a piece of bread of barley and put a date on it and said: This is the condiment of this}}
\hadithdefcmd{abudawud}{3831}{حَدَّثَنَا الْوَلِيدُ بْنُ عُتْبَةَ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بَيْتٌ لاَ تَمْرَ فِيهِ جِيَاعٌ أَهْلُهُ ‏"‏ ‏.‏\hadithno{3831}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2046)}\hadithtrans{’A’ishah reported the Prophet(ﷺ) as saying:A family which has no dates will be hungry}}
\hadithdefcmd{abudawud}{3832}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ، حَدَّثَنَا سَلْمُ بْنُ قُتَيْبَةَ أَبُو قُتَيْبَةَ، عَنْ هَمَّامٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِتَمْرٍ عَتِيقٍ فَجَعَلَ يُفَتِّشُهُ يُخْرِجُ السُّوسَ مِنْهُ ‏.‏\hadithno{3832}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: When the Prophet (ﷺ) was brought some old dates, he began to examine them and remove the worms from them}}
\hadithdefcmd{abudawud}{3833}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا هَمَّامٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُؤْتَى بِالتَّمْرِ فِيهِ دُودٌ فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{3833}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn AbuTalhah: The Prophet (ﷺ) was brought some dates which contained worms. He then mentioned the rest of the tradition to the same effect as the previous (No)}}
\hadithdefcmd{abudawud}{3834}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ جَبَلَةَ بْنِ سُحَيْمٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الإِقْرَانِ إِلاَّ أَنْ تَسْتَأْذِنَ أَصْحَابَكَ ‏.‏\hadithno{3834}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn ‘Umar said:The Messenger of Allah(ﷺ) prohibited anyone taking two dates together with the exception that you ask permission from your companions}}
\hadithdefcmd{abudawud}{3835}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَأْكُلُ الْقِثَّاءَ بِالرُّطَبِ ‏.‏\hadithno{3835}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5447) Sahih Muslim (2043)}\hadithtrans{‘Abd Allah b. Ja’far said:The Prophet(ﷺ) used to eat cucumber with fresh dates}}
\hadithdefcmd{abudawud}{3836}{حَدَّثَنَا سَعِيدُ بْنُ نُصَيْرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْكُلُ الْبِطِّيخَ بِالرُّطَبِ فَيَقُولُ ‏ "‏ نَكْسِرُ حَرَّ هَذَا بِبَرْدِ هَذَا وَبَرْدَ هَذَا بِحَرِّ هَذَا ‏"‏ ‏.‏\hadithno{3836}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) used to eat melon with fresh dates, and he used to say: The heat of the one is broken by the coolness of the other, and the coolness of the one by the heat of the other}}
\hadithdefcmd{abudawud}{3837}{حَدَّثَنَا مُحَمَّدُ بْنُ الْوَزِيرِ، حَدَّثَنَا الْوَلِيدُ بْنُ مَزْيَدٍ، قَالَ سَمِعْتُ ابْنَ جَابِرٍ، قَالَ حَدَّثَنِي سُلَيْمُ بْنُ عَامِرٍ، عَنِ ابْنَىْ، بُسْرٍ السُّلَمِيَّيْنِ قَالاَ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَدَّمْنَا زُبْدًا وَتَمْرًا وَكَانَ يُحِبُّ الزُّبْدَ وَالتَّمْرَ ‏.‏\hadithno{3837}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Busr ibn Atiyyah ibn Busr: The Messenger of Allah (ﷺ) came to visit us and we offered him butter and dates, for he liked butter and dates}}
\hadithdefcmd{abudawud}{3838}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، وَإِسْمَاعِيلُ، عَنْ بُرْدِ بْنِ سِنَانٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَغْزُو مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنُصِيبُ مِنْ آنِيَةِ الْمُشْرِكِينَ وَأَسْقِيَتِهِمْ فَنَسْتَمْتِعُ بِهَا فَلاَ يَعِيبُ ذَلِكَ عَلَيْهِمْ ‏.‏\hadithno{3838}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: I was on an expedition along with the Messenger of Allah (ﷺ). We got the vessels and skins of the polytheists and used them. But he did not object to them (i.e. us) for that (action)}}
\hadithdefcmd{abudawud}{3839}{حَدَّثَنَا نَصْرُ بْنُ عَاصِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ بْنِ زَبْرٍ، عَنْ أَبِي عُبَيْدِ اللَّهِ، مُسْلِمِ بْنِ مِشْكَمٍ عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ إِنَّا نُجَاوِرُ أَهْلَ الْكِتَابِ وَهُمْ يَطْبُخُونَ فِي قُدُورِهِمُ الْخِنْزِيرَ وَيَشْرَبُونَ فِي آنِيَتِهِمُ الْخَمْرَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ وَجَدْتُمْ غَيْرَهَا فَكُلُوا فِيهَا وَاشْرَبُوا وَإِنْ لَمْ تَجِدُوا غَيْرَهَا فَارْحَضُوهَا بِالْمَاءِ وَكُلُوا وَاشْرَبُوا ‏"‏ ‏.‏\hadithno{3839}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Tha’labah al-khushani said that he asked the Messenger of Allah(ﷺ):We live in the neighbourhood of the People of the Book and they cook in their pots(the flesh of) swine and drink wine in their vessels. The Messenger of Allah(ﷺ) said: If you find any other pots, then eat in them and drink. But if you do not find any others, then wash them with water and eat and drink (In them)}}
\hadithdefcmd{abudawud}{3840}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَمَّرَ عَلَيْنَا أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ نَتَلَقَّى عِيرًا لِقُرَيْشٍ وَزَوَّدَنَا جِرَابًا مِنْ تَمْرٍ لَمْ نَجِدْ لَهُ غَيْرَهُ فَكَانَ أَبُو عُبَيْدَةَ يُعْطِينَا تَمْرَةً تَمْرَةً كُنَّا نَمُصُّهَا كَمَا يَمُصُّ الصَّبِيُّ ثُمَّ نَشْرَبُ عَلَيْهَا مِنَ الْمَاءِ فَتَكْفِينَا يَوْمَنَا إِلَى اللَّيْلِ وَكُنَّا نَضْرِبُ بِعِصِيِّنَا الْخَبَطَ ثُمَّ نَبُلُّهُ بِالْمَاءِ فَنَأْكُلُهُ وَانْطَلَقْنَا عَلَى سَاحِلِ الْبَحْرِ فَرُفِعَ لَنَا كَهَيْئَةِ الْكَثِيبِ الضَّخْمِ فَأَتَيْنَاهُ فَإِذَا هُوَ دَابَّةٌ تُدْعَى الْعَنْبَرَ فَقَالَ أَبُو عُبَيْدَةَ مَيْتَةٌ وَلاَ تَحِلُّ لَنَا ثُمَّ قَالَ لاَ بَلْ نَحْنُ رُسُلُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي سَبِيلِ اللَّهِ وَقَدِ اضْطُرِرْتُمْ إِلَيْهِ فَكُلُوا فَأَقَمْنَا عَلَيْهِ شَهْرًا وَنَحْنُ ثَلاَثُمِائَةٍ حَتَّى سَمِنَّا فَلَمَّا قَدِمْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ذَكَرْنَا ذَلِكَ لَهُ فَقَالَ ‏ "‏ هُوَ رِزْقٌ أَخْرَجَهُ اللَّهُ لَكُمْ فَهَلْ مَعَكُمْ مِنْ لَحْمِهِ شَىْءٌ فَتُطْعِمُونَا مِنْهُ ‏"‏ ‏.‏ فَأَرْسَلْنَا مِنْهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَكَلَ ‏.‏\hadithno{3840}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2483) Sahih Muslim (1935)}\hadithtrans{Jabir said:The Messenger of Allah (ﷺ) sent us on an expedition and made Abu ‘Ubaidah b. al-Jarrah our leader. We had to meet a caravan of the Quraish. He gave us a bag of dates as a light meal during the journey. We had nothing except that. Abu ‘Ubaidah would give each of us one date. We used to suck them as a child sucks, and drink water after that and it sufficed us that day till night. We used to beat leaves off the trees with our sticks (for food), wetted them with water and ate them. We then went to the coast of the sea. There appeared to us a body like a great mound. When we came to it, we found that it was an animal called al-anbar. Abu ‘Ubaidah said: It is a carrion, and it is not lawful for us. He then said: No, we are the Messengers of the Apostel of Allah (ﷺ) and we are in the path of Allah. If you are forced by necessity (to eat it), then eat it. We stayed feeding on it for one mouth, till we became fat, and we were three hundred in number. When we came to the Messenger of Allah (ﷺ), we mentioned it to him. He said : It is a provision which Allah has brought forth for you, and give us some to eat if you have any meat of it with you. So we sent some of it to the Messenger of Allah (ﷺ) and he ate (it)}}
\hadithdefcmd{abudawud}{3841}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ فَأْرَةً، وَقَعَتْ، فِي سَمْنٍ فَأُخْبِرَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَلْقُوا مَا حَوْلَهَا وَكُلُوا ‏"‏ ‏.‏\hadithno{3841}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5538)}\hadithtrans{Maimunah said:A mouse fell into clarified butter. The Prophet (ﷺ) was informed of it. He said: Throw what is around it and eat}}
\hadithdefcmd{abudawud}{3842}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَالْحَسَنُ بْنُ عَلِيٍّ، - وَاللَّفْظُ لِلْحَسَنِ - قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَقَعَتِ الْفَأْرَةُ فِي السَّمْنِ فَإِنْ كَانَ جَامِدًا فَأَلْقُوهَا وَمَا حَوْلَهَا وَإِنْ كَانَ مَائِعًا فَلاَ تَقْرَبُوهُ ‏"‏ ‏.‏ قَالَ الْحَسَنُ قَالَ عَبْدُ الرَّزَّاقِ وَرُبَّمَا حَدَّثَ بِهِ مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3842}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When a mouse falls into clarified butter, if it is sold, throw the mouse and what is around it away, but if it is in a liquid state, do not go near it. Al-Hasan said: AbdurRazzaq said: This tradition has been transmitted by Ma'mar, from az-Zuhri, from Ubaydullah ibn Abdullah ibn Abbas, from Maymunah, from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3843}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ بُوذَوَيْهِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ الزُّهْرِيِّ عَنِ ابْنِ الْمُسَيَّبِ ‏.‏\hadithno{3843}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The tradition mentioned above (No. 3833) has also been transmitted by Ibn Abbas from Maymunah, from the Prophet (ﷺ) like the tradition narrated by az-Zuhri, from Ibn al-Musayyab}}
\hadithdefcmd{abudawud}{3844}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ - عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَقَعَ الذُّبَابُ فِي إِنَاءِ أَحَدِكُمْ فَامْقُلُوهُ فَإِنَّ فِي أَحَدِ جَنَاحَيْهِ دَاءً وَفِي الآخَرِ شِفَاءً وَإِنَّهُ يَتَّقِي بِجَنَاحِهِ الَّذِي فِيهِ الدَّاءُ فَلْيَغْمِسْهُ كُلَّهُ ‏"‏ ‏.‏\hadithno{3844}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:when a fly alights in anyone’s vessel, he should plunge it all in, for in one of its wings there is a disease, and in the other is a cure. It prevents the wing of it is which there is a cure, so plunge it all in (the vessel)}}
\hadithdefcmd{abudawud}{3845}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَكَلَ طَعَامًا لَعِقَ أَصَابِعَهُ الثَّلاَثَ وَقَالَ ‏"‏ إِذَا سَقَطَتْ لُقْمَةُ أَحَدِكُمْ فَلْيُمِطْ عَنْهَا الأَذَى وَلْيَأْكُلْهَا وَلاَ يَدَعْهَا لِلشَّيْطَانِ ‏"‏ ‏.‏ وَأَمَرَنَا أَنْ نَسْلُتَ الصَّحْفَةَ وَقَالَ ‏"‏ إِنَّ أَحَدَكُمْ لاَ يَدْرِي فِي أَىِّ طَعَامِهِ يُبَارَكُ لَهُ ‏"‏ ‏.‏\hadithno{3845}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2034)}\hadithtrans{Anas b. Malik said that when the Messenger of Allah (ﷺ) ate food, he licked his three fingers. And he said:If the morsel of one of you falls down, he should wipe away anything injurious on it and eat it and not leave it for the devil. And he ordered us to clean the dish, for one of you does not leave it for the devil. And he ordered us to clean the dish, for one of you does not know in what part of his food the blessing lies}}
\hadithdefcmd{abudawud}{3846}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ مُوسَى بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صَنَعَ لأَحَدِكُمْ خَادِمُهُ طَعَامًا ثُمَّ جَاءَهُ بِهِ وَقَدْ وَلِيَ حَرَّهُ وَدُخَانَهُ فَلْيُقْعِدْهُ مَعَهُ لِيَأْكُلَ فَإِنْ كَانَ الطَّعَامُ مَشْفُوهًا فَلْيَضَعْ فِي يَدِهِ مِنْهُ أَكْلَةً أَوْ أَكْلَتَيْنِ ‏"‏ ‏.‏\hadithno{3846}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2557) Sahih Muslim (1663)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying :If the servant of any of you prepares food for him, and he brings it to him, while he had suffered its heat and smoke. He should make him sit with him to eat. If the food is scanty, he should put one or two morsels in his hand}}
\hadithdefcmd{abudawud}{3847}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَكَلَ أَحَدُكُمْ فَلاَ يَمْسَحَنَّ يَدَهُ بِالْمِنْدِيلِ حَتَّى يَلْعَقَهَا أَوْ يُلْعِقَهَا ‏"‏ ‏.‏\hadithno{3847}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5456) Sahih Muslim (2031)}\hadithtrans{Ibn ‘Abbas reported the Messenger of Allah (ﷺ) as saying :When one of you eats, he must not wipe his hand with a handkerchief till he licks it or gives it to someone to lick}}
\hadithdefcmd{abudawud}{3848}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَعْدٍ، عَنِ ابْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَأْكُلُ بِثَلاَثِ أَصَابِعَ وَلاَ يَمْسَحُ يَدَهُ حَتَّى يَلْعَقَهَا ‏.‏\hadithno{3848}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2032)}\hadithtrans{Ka’b b. Malik said:The Prophet (ﷺ) used to eat with three fingers and not wipe his before licking it}}
\hadithdefcmd{abudawud}{3849}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ ثَوْرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي أُمَامَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا رُفِعَتِ الْمَائِدَةُ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ غَيْرَ مَكْفِيٍّ وَلاَ مُوَدَّعٍ وَلاَ مُسْتَغْنًى عَنْهُ رَبُّنَا ‏"‏ ‏.‏\hadithno{3849}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5458)}\hadithtrans{Abu Umamah said:When the food cloth was removed, the Messenger of Allah (ﷺ) said: “praise be to Allah abundantly and sincerely, of such a nature as is productive of blessing, is not insufficient, Abandoned, or ignored, O our lord.”}}
\hadithdefcmd{abudawud}{3850}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي هَاشِمٍ الْوَاسِطِيِّ، عَنْ إِسْمَاعِيلَ بْنِ رَبَاحٍ، عَنْ أَبِيهِ، أَوْ غَيْرِهِ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا فَرَغَ مِنْ طَعَامِهِ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَنَا وَسَقَانَا وَجَعَلَنَا مُسْلِمِينَ ‏"‏ ‏.‏\hadithno{3850}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: When the Messenger of Allah (ﷺ) finished his food, he said: "Praise be to Allah Who has given us food and drink and made us Muslims}}
\hadithdefcmd{abudawud}{3851}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ أَبِي عَقِيلٍ الْقُرَشِيِّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَكَلَ أَوْ شَرِبَ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَ وَسَقَى وَسَوَّغَهُ وَجَعَلَ لَهُ مَخْرَجًا ‏"‏ ‏.‏\hadithno{3851}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuAyyub al-Ansari: When the Messenger of Allah (ﷺ) ate or drank, he said: "Praise be to Allah Who has given food and drink and made it easy to swallow, and provided an exit for it}}
\hadithdefcmd{abudawud}{3852}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَامَ وَفِي يَدِهِ غَمَرٌ وَلَمْ يَغْسِلْهُ فَأَصَابَهُ شَىْءٌ فَلاَ يَلُومَنَّ إِلاَّ نَفْسَهُ ‏"‏ ‏.‏\hadithno{3852}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone spends the night with grease on his hand which he has not washed away, he can blame only himself if some trouble comes to him}}
\hadithdefcmd{abudawud}{3853}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ يَزِيدَ أَبِي خَالِدٍ الدَّالاَنِيِّ، عَنْ رَجُلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ صَنَعَ أَبُو الْهَيْثَمِ بْنُ التَّيْهَانِ لِلنَّبِيِّ صلى الله عليه وسلم طَعَامًا فَدَعَا النَّبِيَّ صلى الله عليه وسلم وَأَصْحَابَهُ فَلَمَّا فَرَغُوا قَالَ ‏"‏ أَثِيبُوا أَخَاكُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا إِثَابَتُهُ قَالَ ‏"‏ إِنَّ الرَّجُلَ إِذَا دُخِلَ بَيْتُهُ فَأُكِلَ طَعَامُهُ وَشُرِبَ شَرَابُهُ فَدَعَوْا لَهُ فَذَلِكَ إِثَابَتُهُ ‏"‏ ‏.‏\hadithno{3853}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: AbulHaytham ibn at-Tayhan prepared food for the Messenger of Allah (ﷺ), and he invited the Prophet (ﷺ) and his Companions. When they finished (food), the said: If some people enter the house of a man, his food is eaten and his drink is drunk, and they supplicate (to Allah) for him, this is his reward}}
\hadithdefcmd{abudawud}{3854}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَاءَ إِلَى سَعْدِ بْنِ عُبَادَةَ فَجَاءَ بِخُبْزٍ وَزَيْتٍ فَأَكَلَ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَفْطَرَ عِنْدَكُمُ الصَّائِمُونَ وَأَكَلَ طَعَامَكُمُ الأَبْرَارُ وَصَلَّتْ عَلَيْكُمُ الْمَلاَئِكَةُ ‏"‏ ‏.‏\hadithno{3854}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) came to visit Sa'd ibn Ubaydah, and he brought bread and olive oil, and he ate (them). Them). Then the Prophet (ﷺ) said: May the fasting (men) break their fast with you, and the pious eat your food, and the angels pray for blessing on you}}
